--[[
AdiBags - Classic
by Zottelchen
version: 1.0.6
Items from the main game.
]]

local addonName, addon = ...
local AdiBags = LibStub("AceAddon-3.0"):GetAddon("AdiBags")

local L = addon.L
local MatchIDs
local Result = {}

local function AddToSet(...)
  local Set = {}
  for _, l in ipairs({ ... }) do
    for _, v in ipairs(l) do
      Set[v] = true
    end
  end
  return Set
end

local database = {}

-- Bandages
database["Bandages"] = {
  1251, -- Linen Bandage
  2581, -- Heavy Linen Bandage
  3530, -- Wool Bandage
  3531, -- Heavy Wool Bandage
  6450, -- Silk Bandage
  6451, -- Heavy Silk Bandage
  8544, -- Mageweave Bandage
  8545, -- Heavy Mageweave Bandage
  14529, -- Runecloth Bandage
  14530, -- Heavy Runecloth Bandage
  19066, -- Warsong Gulch Runecloth Bandage
  19067, -- Warsong Gulch Mageweave Bandage
  19068, -- Warsong Gulch Silk Bandage
  19307, -- Alterac Heavy Runecloth Bandage
  20065, -- Arathi Basin Mageweave Bandage
  20066, -- Arathi Basin Runecloth Bandage
  20067, -- Arathi Basin Silk Bandage
  20232, -- Defiler's Mageweave Bandage
  20234, -- Defiler's Runecloth Bandage
  20235, -- Defiler's Silk Bandage
  20237, -- Highlander's Mageweave Bandage
  20243, -- Highlander's Runecloth Bandage
  20244, -- Highlander's Silk Bandage
}

-- Consumables
database["Consumables"] = {
  3384, -- Minor Magic Resistance Potion
  3393, -- Recipe: Minor Magic Resistance Potion
  4358, -- Rough Dynamite
  4360, -- Rough Copper Bomb
  4365, -- Coarse Dynamite
  4366, -- Target Dummy
  4367, -- Small Seaforium Charge
  4370, -- Large Copper Bomb
  4374, -- Small Bronze Bomb
  4376, -- Flame Deflector
  4378, -- Heavy Dynamite
  4380, -- Big Bronze Bomb
  4384, -- Explosive Sheep
  4386, -- Ice Deflector
  4388, -- Discombobulator Ray
  4390, -- Iron Grenade
  4391, -- Compact Harvest Reaper Kit
  4392, -- Advanced Target Dummy
  4394, -- Big Iron Bomb
  4395, -- Goblin Land Mine
  4398, -- Large Seaforium Charge
  4403, -- Portable Bronze Mortar
  4852, -- Flash Bomb
  5507, -- Ornate Spyglass
  6265, -- Soul Shard
  6714, -- EZ-Thro Dynamite
  7148, -- Goblin Jumper Cables
  7809, -- Easter Dress
  9036, -- Magic Resistance Potion
  9293, -- Recipe: Magic Resistance Potion
  9299, -- Thermaplugg's Safe Combination
  10507, -- Solid Dynamite
  10514, -- Mithril Frag Bomb
  10562, -- Hi-Explosive Bomb
  10586, -- The Big One
  10646, -- Goblin Sapper Charge
  10757, -- Ward of the Defiler
  10978, -- Small Glimmering Shard
  10998, -- Lesser Astral Essence
  11079, -- Gor'tesh's Lopped Off Head
  11082, -- Greater Astral Essence
  11083, -- Soul Dust
  11084, -- Large Glimmering Shard
  11098, -- Formula: Enchant Cloak - Lesser Shadow Resistance
  11134, -- Lesser Mystic Essence
  11135, -- Greater Mystic Essence
  11137, -- Vision Dust
  11138, -- Small Glowing Shard
  11139, -- Large Glowing Shard
  11174, -- Lesser Nether Essence
  11175, -- Greater Nether Essence
  11177, -- Small Radiant Shard
  11178, -- Large Radiant Shard
  11224, -- Formula: Enchant Shield - Frost Resistance
  11590, -- Mechanical Repair Kit
  13140, -- Blood Red Key
  15993, -- Thorium Grenade
  16005, -- Dark Iron Bomb
  16023, -- Masterwork Target Dummy
  16040, -- Arcane Bomb
  18232, -- Field Repair Bot 74A
  18587, -- Goblin Jumper Cables XL
  18588, -- EZ-Thro Dynamite II
  18594, -- Powerful Seaforium Charge
  18641, -- Dense Dynamite
  18645, -- Gnomish Alarm-o-Bot
  20725, -- Nexus Crystal
}

-- Foods and Drinks
database["FoodsandDrinks"] = {
  117, -- Tough Jerky
  159, -- Refreshing Spring Water
  414, -- Dalaran Sharp
  422, -- Dwarven Mild
  724, -- Goretusk Liver Pie
  733, -- Westfall Stew
  787, -- Slitherskin Mackerel
  961, -- Healing Herb
  1017, -- Seasoned Wolf Kabob
  1082, -- Redridge Goulash
  1113, -- Conjured Bread
  1114, -- Conjured Rye
  1179, -- Ice Cold Milk
  1205, -- Melon Juice
  1401, -- Riverpaw Tea Leaf
  1487, -- Conjured Pumpernickel
  1645, -- Moonberry Juice
  1707, -- Stormwind Brie
  1708, -- Sweet Nectar
  2070, -- Darnassian Bleu
  2136, -- Conjured Purified Water
  2287, -- Haunch of Meat
  2288, -- Conjured Fresh Water
  2593, -- Flask of Stormwind Tawny
  2594, -- Flagon of Dwarven Mead
  2595, -- Jug of Badlands Bourbon
  2596, -- Skin of Dwarven Stout
  2679, -- Charred Wolf Meat
  2680, -- Spiced Wolf Meat
  2681, -- Roasted Boar Meat
  2682, -- Cooked Crab Claw
  2683, -- Crab Cake
  2684, -- Coyote Steak
  2685, -- Succulent Pork Ribs
  2686, -- Thunder Ale
  2687, -- Dry Pork Ribs
  2723, -- Bottle of Dalaran Noir
  2888, -- Beer Basted Boar Ribs
  2894, -- Rhapsody Malt
  3220, -- Blood Sausage
  3662, -- Crocolisk Steak
  3663, -- Murloc Fin Soup
  3664, -- Crocolisk Gumbo
  3665, -- Curiously Tasty Omelet
  3666, -- Gooey Spider Cake
  3703, -- Southshore Stout
  3726, -- Big Bear Steak
  3727, -- Hot Lion Chops
  3728, -- Tasty Lion Steak
  3729, -- Soothing Turtle Bisque
  3770, -- Mutton Chop
  3771, -- Wild Hog Shank
  3772, -- Conjured Spring Water
  3927, -- Fine Aged Cheddar
  4457, -- Barbecued Buzzard Wing
  4536, -- Shiny Red Apple
  4537, -- Tel'Abim Banana
  4538, -- Snapvine Watermelon
  4539, -- Goldenbark Apple
  4540, -- Tough Hunk of Bread
  4541, -- Freshly Baked Bread
  4542, -- Moist Cornbread
  4544, -- Mulgore Spice Bread
  4592, -- Longjaw Mud Snapper
  4593, -- Bristle Whisker Catfish
  4594, -- Rockscale Cod
  4595, -- Junglevine Wine
  4599, -- Cured Ham Steak
  4600, -- Cherry Grog
  4601, -- Soft Banana Bread
  4602, -- Moon Harvest Pumpkin
  4604, -- Forest Mushroom Cap
  4605, -- Red-Speckled Mushroom
  4606, -- Spongy Morel
  4607, -- Delicious Cave Mold
  4608, -- Raw Black Truffle
  4656, -- Small Pumpkin
  4791, -- Enchanted Water
  5057, -- Ripe Watermelon
  5066, -- Fissure Plant
  5095, -- Rainbow Fin Albacore
  5205, -- Sprouted Frond
  5342, -- Raptor Punch
  5349, -- Conjured Muffin
  5350, -- Conjured Water
  5472, -- Kaldorei Spider Kabob
  5473, -- Scorpid Surprise
  5474, -- Roasted Kodo Meat
  5476, -- Fillet of Frenzy
  5477, -- Strider Stew
  5478, -- Dig Rat Stew
  5479, -- Crispy Lizard Tail
  5480, -- Lean Venison
  5512, -- Healthstone
  5513, -- Mana Jade
  5525, -- Boiled Clams
  5526, -- Clam Chowder
  5527, -- Goblin Deviled Clams
  6038, -- Giant Clam Scorcho
  6290, -- Brilliant Smallfish
  6299, -- Sickly Looking Fish
  6316, -- Loch Frenzy Delight
  6458, -- Oil Covered Fish
  6522, -- Deviate Fish
  6657, -- Savory Deviate Delight
  6807, -- Frog Leg Stew
  6887, -- Spotted Yellowtail
  6888, -- Herb Baked Egg
  6890, -- Smoked Bear Meat
  7097, -- Leg Meat
  7228, -- Tigule's Strawberry Ice Cream
  7676, -- Thistle Tea
  7806, -- Lollipop
  7807, -- Candy Bar
  7808, -- Chocolate Square
  8007, -- Mana Citrine
  8008, -- Mana Ruby
  8075, -- Conjured Sourdough
  8076, -- Conjured Sweet Roll
  8077, -- Conjured Mineral Water
  8078, -- Conjured Sparkling Water
  8079, -- Conjured Crystal Water
  8364, -- Mithril Head Trout
  8766, -- Morning Glory Dew
  8932, -- Alterac Swiss
  8948, -- Dried King Bolete
  8950, -- Homemade Cherry Pie
  8952, -- Roasted Quail
  8953, -- Deep Fried Plantains
  8957, -- Spinefin Halibut
  9260, -- Volatile Rum
  9451, -- Bubbling Water
  10841, -- Goldthorn Tea
  11109, -- Special Chicken Feed
  11415, -- Mixed Berries
  11444, -- Grim Guzzler Boar
  11584, -- Cactus Apple Surprise
  12209, -- Lean Wolf Steak
  12210, -- Roast Raptor
  12212, -- Jungle Stew
  12213, -- Carrion Surprise
  12214, -- Mystery Stew
  12215, -- Heavy Kodo Stew
  12216, -- Spiced Chili Crab
  12217, -- Dragonbreath Chili
  12218, -- Monster Omelet
  12224, -- Crispy Bat Wing
  12238, -- Darkshore Grouper
  13546, -- Bloodbelly Fish
  13724, -- Enriched Manna Biscuit
  13755, -- Winter Squid
  13810, -- Blessed Sunfruit
  13813, -- Blessed Sunfruit Juice
  13851, -- Hot Wolf Ribs
  13893, -- Large Raw Mightfish
  13927, -- Cooked Glossy Mightfish
  13928, -- Grilled Squid
  13929, -- Hot Smoked Bass
  13930, -- Filet of Redgill
  13931, -- Nightfin Soup
  13932, -- Poached Sunscale Salmon
  13933, -- Lobster Stew
  13934, -- Mightfish Steak
  13935, -- Baked Salmon
  14894, -- Lily Root
  16166, -- Bean Soup
  16167, -- Versicolor Treat
  16168, -- Heaven Peach
  16169, -- Wild Ricecake
  16170, -- Steamed Mandu
  16766, -- Undermine Clam Chowder
  17119, -- Deeprun Rat Kabob
  17196, -- Holiday Spirits
  17197, -- Gingerbread Cookie
  17198, -- Winter Veil Egg Nog
  17222, -- Spider Sausage
  17344, -- Candy Cane
  17402, -- Greatfather's Winter Ale
  17403, -- Steamwheedle Fizzy Spirits
  17404, -- Blended Bean Brew
  17406, -- Holiday Cheesewheel
  17407, -- Graccu's Homemade Meat Pie
  17408, -- Spicy Beefstick
  17747, -- Razorlash Root
  18045, -- Tender Wolf Steak
  18254, -- Runn Tum Tuber Surprise
  18255, -- Runn Tum Tuber
  18287, -- Evermurky
  18288, -- Molasses Firewater
  18300, -- Hyjal Nectar
  18632, -- Moonbrook Riot Taffy
  18633, -- Styleen's Sour Suckerpop
  18635, -- Bellara's Nutterbar
  19060, -- Warsong Gulch Enriched Ration
  19061, -- Warsong Gulch Iron Ration
  19062, -- Warsong Gulch Field Ration
  19221, -- Darkmoon Special Reserve
  19222, -- Cheap Beer
  19223, -- Darkmoon Dog
  19224, -- Red Hot Wings
  19225, -- Deep Fried Candybar
  19299, -- Fizzy Faire Drink
  19300, -- Bottled Winterspring Water
  19301, -- Alterac Manna Biscuit
  19304, -- Spiced Beef Jerky
  19305, -- Pickled Kodo Foot
  19306, -- Crunchy Frog
  19318, -- Bottled Alterac Spring Water
  19696, -- Harvest Bread
  19994, -- Harvest Fruit
  19995, -- Harvest Boar
  19996, -- Harvest Fish
  19997, -- Harvest Nectar
  20062, -- Arathi Basin Enriched Ration
  20063, -- Arathi Basin Field Ration
  20064, -- Arathi Basin Iron Ration
  20074, -- Heavy Crocolisk Stew
  20222, -- Defiler's Enriched Ration
  20223, -- Defiler's Field Ration
  20224, -- Defiler's Iron Ration
  20225, -- Highlander's Enriched Ration
  20226, -- Highlander's Field Ration
  20227, -- Highlander's Iron Ration
  20388, -- Lollipop
  20389, -- Candy Corn
  20390, -- Candy Bar
  20452, -- Smoked Desert Dumplings
  20516, -- Bobbing Apple
  20709, -- Rumsey Rum Light
  21023, -- Dirge's Kickin' Chimaerok Chops
  21030, -- Darnassus Kimchi Pie
  21031, -- Cabbage Kimchi
  21033, -- Radish Kimchi
  21072, -- Smoked Sagefish
  21114, -- Rumsey Rum Dark
  21151, -- Rumsey Rum Black Label
  21215, -- Graccu's Mince Meat Fruitcake
  21217, -- Sagefish Delight
  21235, -- Winter Veil Roast
  21241, -- Winter Veil Eggnog
  21254, -- Winter Veil Cookie
  21537, -- Festival Dumplings
  21552, -- Striped Yellowtail
  21721, -- Moonglow
  22236, -- Buttermilk Delight
  22237, -- Dark Desire
  22238, -- Very Berry Cream
  22239, -- Sweet Surprise
  22324, -- Winter Kimchi
  22895, -- Conjured Cinnamon Roll
  23160, -- Friendship Bread
  23161, -- Freshly-Squeezed Lemonade
}

-- Other Consumables
database["OtherConsumables"] = {
  954, -- Scroll of Strength
  955, -- Scroll of Intellect
  1127, -- Flash Bundle
  1177, -- Oil of Olaf
  1180, -- Scroll of Stamina
  1181, -- Scroll of Versatility
  1187, -- Spiked Collar
  1399, -- Magic Candle
  1477, -- Scroll of Agility II
  1478, -- Scroll of Protection II
  1711, -- Scroll of Stamina II
  1712, -- Scroll of Versatility II
  2091, -- Magic Dust
  2289, -- Scroll of Strength II
  2290, -- Scroll of Intellect II
  3012, -- Scroll of Agility
  3013, -- Scroll of Protection
  3434, -- Slumber Sand
  4419, -- Scroll of Intellect III
  4421, -- Scroll of Protection III
  4422, -- Scroll of Stamina III
  4424, -- Scroll of Versatility III
  4425, -- Scroll of Agility III
  4426, -- Scroll of Strength III
  4479, -- Burning Charm
  4480, -- Thundering Charm
  4481, -- Cresting Charm
  5042, -- Red Ribboned Wrapping Paper
  5043, -- Red Ribboned Gift
  5044, -- Blue Ribboned Gift
  5048, -- Blue Ribboned Wrapping Paper
  5206, -- Bogling Root
  5232, -- Soulstone
  5457, -- Severed Voodoo Claw
  5740, -- Red Fireworks Rocket
  5951, -- Moist Towelette
  6452, -- Anti-Venom
  6453, -- Strong Anti-Venom
  6464, -- Wailing Essence
  6781, -- Bartleby's Mug
  6782, -- Marshal Haggard's Badge
  6812, -- Case of Elunite
  7266, -- Ur's Treatise on Shadow Magic
  7627, -- Dolanaar Delivery
  8048, -- Emerald Dreamcatcher
  8444, -- Executioner's Key
  8548, -- Divino-Matic Rod
  8956, -- Oil of Immolation
  9312, -- Blue Firework
  9313, -- Green Firework
  9314, -- Red Streaks Firework
  9315, -- Yellow Rose Firework
  9317, -- Red, White and Blue Firework
  9318, -- Red Firework
  9546, -- Simple Scroll
  9569, -- Hallowed Scroll
  10305, -- Scroll of Protection IV
  10306, -- Scroll of Versatility IV
  10307, -- Scroll of Stamina IV
  10308, -- Scroll of Intellect IV
  10309, -- Scroll of Agility IV
  10310, -- Scroll of Strength IV
  10621, -- Runed Scroll
  10684, -- Colossal Parachute
  10687, -- Empty Vial Labeled #1
  10688, -- Empty Vial Labeled #2
  10689, -- Empty Vial Labeled #3
  10690, -- Empty Vial Labeled #4
  11325, -- Dark Iron Ale Mug
  11914, -- Empty Cursed Ooze Jar
  11948, -- Empty Tainted Ooze Jar
  11953, -- Empty Pure Sample Jar
  12533, -- Roughshod Pike
  12586, -- Immature Venom Sac
  12712, -- Warosh's Mojo
  12884, -- Arnak's Hoof
  12885, -- Pamela's Doll
  12894, -- Joseph's Wedding Ring
  13155, -- Resonating Skull
  13508, -- Eye of Arachnida
  13509, -- Clutch of Foresight
  13514, -- Wail of the Banshee
  13703, -- Kodo Bone
  14542, -- Kravel's Crate
  15778, -- Mechanical Yeti
  15869, -- Silver Skeleton Key
  15870, -- Golden Skeleton Key
  15871, -- Truesilver Skeleton Key
  15872, -- Arcanite Skeleton Key
  16282, -- Bundle of Hides
  17048, -- Rumsey Rum
  17302, -- Blue Ribboned Holiday Gift
  17303, -- Blue Ribboned Wrapping Paper
  17304, -- Green Ribboned Wrapping Paper
  17305, -- Green Ribboned Holiday Gift
  17307, -- Purple Ribboned Wrapping Paper
  17308, -- Purple Ribboned Holiday Gift
  18169, -- Flame Mantle of the Dawn
  18170, -- Frost Mantle of the Dawn
  18171, -- Arcane Mantle of the Dawn
  18172, -- Nature Mantle of the Dawn
  18173, -- Shadow Mantle of the Dawn
  18182, -- Chromatic Mantle of the Dawn
  18269, -- Gordok Green Grog
  18284, -- Kreeg's Stout Beatdown
  18297, -- Thornling Seed
  18606, -- Alliance Battle Standard
  18607, -- Horde Battle Standard
  18640, -- Happy Fun Rock
  18662, -- Heavy Leather Ball
  19026, -- Snake Burst Firework
  19045, -- Stormpike Battle Standard
  19046, -- Frostwolf Battle Standard
  19150, -- Sentinel Basic Care Package
  19151, -- Sentinel Standard Care Package
  19152, -- Sentinel Advanced Care Package
  19153, -- Outrider Advanced Care Package
  19154, -- Outrider Basic Care Package
  19155, -- Outrider Standard Care Package
  19183, -- Hourglass Sand
  19425, -- Mysterious Lockbox
  19440, -- Powerful Anti-Venom
  20228, -- Defiler's Advanced Care Package
  20229, -- Defiler's Basic Care Package
  20230, -- Defiler's Standard Care Package
  20231, -- Arathor Advanced Care Package
  20233, -- Arathor Basic Care Package
  20236, -- Arathor Standard Care Package
  20391, -- Gnome Male Mask
  20392, -- Gnome Female Mask
  20397, -- Hallowed Wand - Pirate
  20398, -- Hallowed Wand - Ninja
  20399, -- Hallowed Wand - Leper Gnome
  20409, -- Hallowed Wand - Ghost
  20410, -- Hallowed Wand - Bat
  20411, -- Hallowed Wand - Skeleton
  20413, -- Hallowed Wand - Random
  20414, -- Hallowed Wand - Wisp
  20470, -- Solanian's Scrying Orb
  20471, -- Scroll of Scourge Magic
  20472, -- Solanian's Journal
  20557, -- Hallow's End Pumpkin Treat
  20561, -- Dwarf Male Mask
  20562, -- Dwarf Female Mask
  20563, -- Night Elf Female Mask
  20564, -- Night Elf Male Mask
  20565, -- Human Female Mask
  20566, -- Human Male Mask
  20567, -- Troll Female Mask
  20568, -- Troll Male Mask
  20569, -- Orc Female Mask
  20570, -- Orc Male Mask
  20571, -- Tauren Female Mask
  20572, -- Tauren Male Mask
  20573, -- Undead Male Mask
  20574, -- Undead Female Mask
  21212, -- Fresh Holly
  21325, -- Mechanical Greench
  21711, -- Lunar Festival Invitation
  21740, -- Small Rocket Recipes
  21741, -- Cluster Rocket Recipes
  21742, -- Large Rocket Recipes
  21743, -- Large Cluster Rocket Recipes
  21744, -- Lucky Rocket Cluster
  21745, -- Elder's Moonstone
  21746, -- Lucky Red Envelope
  23211, -- Toasted Smorc
  23246, -- Fiery Festival Brew
  23326, -- Midsummer Sausage
  23327, -- Fire-Toasted Bun
  23435, -- Elderberry Pie
}

-- Elixirs
database["Elixirs"] = {
  2454, -- Elixir of Lion's Strength
  2457, -- Elixir of Minor Agility
  2458, -- Elixir of Minor Fortitude
  3382, -- Weak Troll's Blood Elixir
  3383, -- Elixir of Wisdom
  3388, -- Strong Troll's Blood Elixir
  3389, -- Elixir of Defense
  3390, -- Elixir of Lesser Agility
  3391, -- Elixir of Ogre's Strength
  3825, -- Elixir of Fortitude
  3826, -- Major Troll's Blood Elixir
  3828, -- Elixir of Detect Lesser Invisibility
  5996, -- Elixir of Water Breathing
  5997, -- Elixir of Minor Defense
  6373, -- Elixir of Firepower
  6662, -- Elixir of Giant Growth
  8529, -- Noggenfogger Elixir
  8827, -- Elixir of Water Walking
  8949, -- Elixir of Agility
  8951, -- Elixir of Greater Defense
  9088, -- Gift of Arthas
  9154, -- Elixir of Detect Undead
  9155, -- Arcane Elixir
  9179, -- Elixir of Greater Intellect
  9187, -- Elixir of Greater Agility
  9197, -- Elixir of Dream Vision
  9206, -- Elixir of Giants
  9224, -- Elixir of Demonslaying
  9233, -- Elixir of Detect Demon
  9264, -- Elixir of Shadow Power
  10592, -- Catseye Elixir
  12820, -- Winterfall Firewater
  13445, -- Elixir of Superior Defense
  13447, -- Elixir of the Sages
  13452, -- Elixir of the Mongoose
  13453, -- Elixir of Brute Force
  13454, -- Greater Arcane Elixir
  17708, -- Elixir of Frost Power
  18294, -- Elixir of Greater Water Breathing
  20004, -- Mighty Troll's Blood Elixir
  20007, -- Mageblood Elixir
  21546, -- Elixir of Greater Firepower
}

-- Flasks
database["Flasks"] = {
  13510, -- Flask of the Titans
  13511, -- Flask of Distilled Wisdom
  13512, -- Flask of Supreme Power
}

-- Potions
database["Potions"] = {
  118, -- Minor Healing Potion
  858, -- Lesser Healing Potion
  929, -- Healing Potion
  1710, -- Greater Healing Potion
  2455, -- Minor Mana Potion
  2456, -- Minor Rejuvenation Potion
  2459, -- Swiftness Potion
  3385, -- Lesser Mana Potion
  3386, -- Potion of Curing
  3387, -- Limited Invulnerability Potion
  3823, -- Lesser Invisibility Potion
  3827, -- Mana Potion
  3928, -- Superior Healing Potion
  4596, -- Discolored Healing Potion
  4623, -- Lesser Stoneshield Potion
  5631, -- Rage Potion
  5633, -- Great Rage Potion
  5634, -- Free Action Potion
  6048, -- Shadow Protection Potion
  6049, -- Fire Protection Potion
  6050, -- Frost Protection Potion
  6051, -- Holy Protection Potion
  6052, -- Nature Protection Potion
  6149, -- Greater Mana Potion
  6372, -- Swim Speed Potion
  9030, -- Restorative Potion
  9144, -- Wildvine Potion
  9172, -- Invisibility Potion
  12190, -- Dreamless Sleep Potion
  13442, -- Mighty Rage Potion
  13443, -- Superior Mana Potion
  13444, -- Major Mana Potion
  13446, -- Major Healing Potion
  13455, -- Greater Stoneshield Potion
  13456, -- Greater Frost Protection Potion
  13457, -- Greater Fire Protection Potion
  13458, -- Greater Nature Protection Potion
  13459, -- Greater Shadow Protection Potion
  13460, -- Greater Holy Protection Potion
  13461, -- Greater Arcane Protection Potion
  13462, -- Purification Potion
  13506, -- Potion of Petrification
  17348, -- Major Healing Draught
  17349, -- Superior Healing Draught
  17351, -- Major Mana Draught
  17352, -- Superior Mana Draught
  18253, -- Major Rejuvenation Potion
  18839, -- Combat Healing Potion
  18841, -- Combat Mana Potion
  20002, -- Greater Dreamless Sleep Potion
  20008, -- Living Action Potion
}

-- Healthstone
database["Healthstone"] = {
  5512, -- Healthstone
}

-- Alchemy Recipes
database["AlchemyRecipes"] = {
  2553, -- Recipe: Elixir of Minor Agility
  2555, -- Recipe: Swiftness Potion
  3394, -- Recipe: Potion of Curing
  3395, -- Recipe: Limited Invulnerability Potion
  3396, -- Recipe: Elixir of Lesser Agility
  3830, -- Recipe: Elixir of Fortitude
  3831, -- Recipe: Major Troll's Blood Elixir
  3832, -- Recipe: Elixir of Detect Lesser Invisibility
  4597, -- Recipe: Discolored Healing Potion
  4624, -- Recipe: Lesser Stoneshield Potion
  5640, -- Recipe: Rage Potion
  5642, -- Recipe: Free Action Potion
  5643, -- Recipe: Great Rage Potion
  6053, -- Recipe: Holy Protection Potion
  6054, -- Recipe: Shadow Protection Potion
  6055, -- Recipe: Fire Protection Potion
  6056, -- Recipe: Frost Protection Potion
  6057, -- Recipe: Nature Protection Potion
  6068, -- Recipe: Shadow Oil
  6211, -- Recipe: Elixir of Ogre's Strength
  6454, -- Manual: Strong Anti-Venom
  6663, -- Recipe: Elixir of Giant Growth
  9294, -- Recipe: Wildvine Potion
  9295, -- Recipe: Invisibility Potion
  9296, -- Recipe: Gift of Arthas
  9297, -- Recipe: Elixir of Dream Vision
  9298, -- Recipe: Elixir of Giants
  9300, -- Recipe: Elixir of Demonslaying
  9301, -- Recipe: Elixir of Shadow Power
  9302, -- Recipe: Ghost Dye
  9303, -- Recipe: Philosopher's Stone
  9304, -- Recipe: Transmute Iron to Gold
  9305, -- Recipe: Transmute Mithril to Truesilver
  10644, -- Recipe: Goblin Rocket Fuel
  12958, -- Recipe: Transmute Arcanite
  13476, -- Recipe: Mighty Rage Potion
  13477, -- Recipe: Superior Mana Potion
  13478, -- Recipe: Elixir of Superior Defense
  13479, -- Recipe: Elixir of the Sages
  13480, -- Recipe: Major Healing Potion
  13481, -- Recipe: Elixir of Brute Force
  13482, -- Recipe: Transmute Air to Fire
  13483, -- Recipe: Transmute Fire to Earth
  13484, -- Recipe: Transmute Earth to Water
  13485, -- Recipe: Transmute Water to Air
  13486, -- Recipe: Transmute Undeath to Water
  13487, -- Recipe: Transmute Water to Undeath
  13488, -- Recipe: Transmute Life to Earth
  13489, -- Recipe: Transmute Earth to Life
  13490, -- Recipe: Greater Stoneshield Potion
  13491, -- Recipe: Elixir of the Mongoose
  13492, -- Recipe: Purification Potion
  13493, -- Recipe: Greater Arcane Elixir
  13494, -- Recipe: Greater Fire Protection Potion
  13495, -- Recipe: Greater Frost Protection Potion
  13496, -- Recipe: Greater Nature Protection Potion
  13497, -- Recipe: Greater Arcane Protection Potion
  13499, -- Recipe: Greater Shadow Protection Potion
  13501, -- Recipe: Major Mana Potion
  13517, -- Recipe: Alchemist Stone
  13518, -- Recipe: Potion of Petrification
  13519, -- Recipe: Flask of the Titans
  13520, -- Recipe: Flask of Distilled Wisdom
  13521, -- Recipe: Flask of Supreme Power
  14634, -- Recipe: Frost Oil
  17709, -- Recipe: Elixir of Frost Power
  18257, -- Recipe: Major Rejuvenation Potion
  19442, -- Recipe: Powerful Anti-Venom
  20011, -- Recipe: Mageblood Elixir
  20012, -- Recipe: Greater Dreamless Sleep Potion
  20013, -- Recipe: Living Action Potion
  20014, -- Recipe: Mighty Troll's Blood Elixir
  20761, -- Recipe: Transmute Elemental Fire
  21547, -- Recipe: Elixir of Greater Firepower
}

-- Blacksmithing Recipes
database["BlacksmithingRecipes"] = {
  2881, -- Plans: Runed Copper Breastplate
  2882, -- Plans: Silvered Bronze Shoulders
  2883, -- Plans: Deadly Bronze Poniard
  3608, -- Plans: Mighty Iron Hammer
  3609, -- Plans: Copper Chain Vest
  3610, -- Plans: Gemmed Copper Gauntlets
  3611, -- Plans: Green Iron Boots
  3612, -- Plans: Green Iron Gauntlets
  3866, -- Plans: Jade Serpentblade
  3867, -- Plans: Golden Iron Destroyer
  3868, -- Plans: Frost Tiger Blade
  3869, -- Plans: Shadow Crescent Axe
  3870, -- Plans: Green Iron Shoulders
  3871, -- Plans: Golden Scale Shoulders
  3872, -- Plans: Golden Scale Leggings
  3873, -- Plans: Golden Scale Cuirass
  3874, -- Plans: Polished Steel Boots
  3875, -- Plans: Golden Scale Boots
  5543, -- Plans: Iridescent Hammer
  5578, -- Plans: Silvered Bronze Breastplate
  6044, -- Plans: Iron Shield Spike
  6045, -- Plans: Iron Counterweight
  6046, -- Plans: Steel Weapon Chain
  6047, -- Plans: Golden Scale Coif
  6735, -- Plans: Ironforge Breastplate
  7975, -- Plans: Heavy Mithril Pants
  7976, -- Plans: Mithril Shield Spike
  7978, -- Plans: Barbaric Iron Shoulders
  7979, -- Plans: Barbaric Iron Breastplate
  7980, -- Plans: Barbaric Iron Helm
  7981, -- Plans: Barbaric Iron Boots
  7982, -- Plans: Barbaric Iron Gloves
  7983, -- Plans: Ornate Mithril Pants
  7984, -- Plans: Ornate Mithril Gloves
  7985, -- Plans: Ornate Mithril Shoulder
  7989, -- Plans: Mithril Spurs
  7990, -- Plans: Heavy Mithril Helm
  7991, -- Plans: Mithril Scale Shoulders
  7992, -- Plans: Blue Glittering Axe
  7993, -- Plans: Dazzling Mithril Rapier
  7995, -- Plans: Mithril Scale Bracers
  8028, -- Plans: Runed Mithril Hammer
  8029, -- Plans: Wicked Mithril Blade
  8030, -- Plans: Ebon Shiv
  9367, -- Plans: Golden Scale Gauntlets
  10424, -- Plans: Silvered Bronze Leggings
  10713, -- Plans: Inlaid Mithril Cylinder
  10858, -- Plans: Solid Iron Maul
  11610, -- Plans: Dark Iron Pulverizer
  11611, -- Plans: Dark Iron Sunderer
  11612, -- Plans: Dark Iron Plate
  11614, -- Plans: Dark Iron Mail
  11615, -- Plans: Dark Iron Shoulders
  12162, -- Plans: Hardened Iron Shortsword
  12163, -- Plans: Moonsteel Broadsword
  12164, -- Plans: Massive Iron Axe
  12261, -- Plans: Searing Golden Blade
  12682, -- Plans: Thorium Armor
  12683, -- Plans: Thorium Belt
  12684, -- Plans: Thorium Bracers
  12685, -- Plans: Radiant Belt
  12687, -- Plans: Imperial Plate Shoulders
  12688, -- Plans: Imperial Plate Belt
  12689, -- Plans: Radiant Breastplate
  12690, -- Plans: Imperial Plate Bracers
  12691, -- Plans: Wildthorn Mail
  12692, -- Plans: Thorium Shield Spike
  12693, -- Plans: Thorium Boots
  12694, -- Plans: Thorium Helm
  12695, -- Plans: Radiant Gloves
  12696, -- Plans: Demon Forged Breastplate
  12697, -- Plans: Radiant Boots
  12698, -- Plans: Dawnbringer Shoulders
  12699, -- Plans: Fiery Plate Gauntlets
  12700, -- Plans: Imperial Plate Boots
  12701, -- Plans: Imperial Plate Helm
  12702, -- Plans: Radiant Circlet
  12703, -- Plans: Storm Gauntlets
  12704, -- Plans: Thorium Leggings
  12705, -- Plans: Imperial Plate Chest
  12706, -- Plans: Runic Plate Shoulders
  12707, -- Plans: Runic Plate Boots
  12711, -- Plans: Whitesoul Helm
  12713, -- Plans: Radiant Leggings
  12714, -- Plans: Runic Plate Helm
  12715, -- Plans: Imperial Plate Leggings
  12716, -- Plans: Helm of the Great Chief
  12717, -- Plans: Lionheart Helm
  12718, -- Plans: Runic Breastplate
  12719, -- Plans: Runic Plate Leggings
  12720, -- Plans: Stronghold Gauntlets
  12725, -- Plans: Enchanted Thorium Helm
  12726, -- Plans: Enchanted Thorium Leggings
  12727, -- Plans: Enchanted Thorium Breastplate
  12728, -- Plans: Invulnerable Mail
  12819, -- Plans: Ornate Thorium Handaxe
  12821, -- Plans: Dawn's Edge
  12823, -- Plans: Huge Thorium Battleaxe
  12824, -- Plans: Enchanted Battlehammer
  12825, -- Plans: Blazing Rapier
  12827, -- Plans: Serenity
  12828, -- Plans: Volcanic Hammer
  12830, -- Plans: Corruption
  12833, -- Plans: Hammer of the Titans
  12834, -- Plans: Arcanite Champion
  12835, -- Plans: Annihilator
  12836, -- Plans: Frostguard
  12837, -- Plans: Masterwork Stormhammer
  12838, -- Plans: Arcanite Reaper
  12839, -- Plans: Heartseeker
  17049, -- Plans: Fiery Chain Girdle
  17051, -- Plans: Dark Iron Bracers
  17052, -- Plans: Dark Iron Leggings
  17053, -- Plans: Fiery Chain Shoulders
  17059, -- Plans: Dark Iron Reaver
  17060, -- Plans: Dark Iron Destroyer
  17706, -- Plans: Edge of Winter
  18264, -- Plans: Elemental Sharpening Stone
  18592, -- Plans: Sulfuron Hammer
  19202, -- Plans: Heavy Timbermaw Belt
  19203, -- Plans: Girdle of the Dawn
  19204, -- Plans: Heavy Timbermaw Boots
  19205, -- Plans: Gloves of the Dawn
  19206, -- Plans: Dark Iron Helm
  19207, -- Plans: Dark Iron Gauntlets
  19208, -- Plans: Black Amnesty
  19209, -- Plans: Blackfury
  19210, -- Plans: Ebon Hand
  19211, -- Plans: Blackguard
  19212, -- Plans: Nightfall
  19776, -- Plans: Bloodsoul Breastplate
  19777, -- Plans: Bloodsoul Shoulders
  19778, -- Plans: Bloodsoul Gauntlets
  19779, -- Plans: Darksoul Breastplate
  19780, -- Plans: Darksoul Leggings
  19781, -- Plans: Darksoul Shoulders
  20040, -- Plans: Dark Iron Boots
  20553, -- Plans: Darkrune Gauntlets
  20554, -- Plans: Darkrune Breastplate
  20555, -- Plans: Darkrune Helm
  22209, -- Plans: Heavy Obsidian Belt
  22214, -- Plans: Light Obsidian Belt
  22219, -- Plans: Jagged Obsidian Shield
  22220, -- Plans: Black Grasp of the Destroyer
  22221, -- Plans: Obsidian Mail Tunic
  22222, -- Plans: Thick Obsidian Breastplate
  22388, -- Plans: Titanic Leggings
  22389, -- Plans: Sageblade
  22390, -- Plans: Persuader
  22766, -- Plans: Ironvine Breastplate
  22767, -- Plans: Ironvine Gloves
  22768, -- Plans: Ironvine Belt
}

-- Cooking Recipes
database["CookingRecipes"] = {
  728, -- Recipe: Westfall Stew
  2697, -- Recipe: Goretusk Liver Pie
  2698, -- Recipe: Cooked Crab Claw
  2699, -- Recipe: Redridge Goulash
  2700, -- Recipe: Succulent Pork Ribs
  2701, -- Recipe: Seasoned Wolf Kabob
  2889, -- Recipe: Beer Basted Boar Ribs
  3678, -- Recipe: Crocolisk Steak
  3679, -- Recipe: Blood Sausage
  3680, -- Recipe: Murloc Fin Soup
  3681, -- Recipe: Crocolisk Gumbo
  3682, -- Recipe: Curiously Tasty Omelet
  3683, -- Recipe: Gooey Spider Cake
  3734, -- Recipe: Big Bear Steak
  3735, -- Recipe: Hot Lion Chops
  3736, -- Recipe: Tasty Lion Steak
  3737, -- Recipe: Soothing Turtle Bisque
  4609, -- Recipe: Barbecued Buzzard Wing
  5482, -- Recipe: Kaldorei Spider Kabob
  5483, -- Recipe: Scorpid Surprise
  5484, -- Recipe: Roasted Kodo Meat
  5485, -- Recipe: Fillet of Frenzy
  5486, -- Recipe: Strider Stew
  5487, -- Recipe: Dig Rat Stew
  5488, -- Recipe: Crispy Lizard Tail
  5489, -- Recipe: Lean Venison
  5528, -- Recipe: Clam Chowder
  6039, -- Recipe: Giant Clam Scorcho
  6325, -- Recipe: Brilliant Smallfish
  6326, -- Recipe: Slitherskin Mackerel
  6328, -- Recipe: Longjaw Mud Snapper
  6329, -- Recipe: Loch Frenzy Delight
  6330, -- Recipe: Bristle Whisker Catfish
  6368, -- Recipe: Rainbow Fin Albacore
  6369, -- Recipe: Rockscale Cod
  6661, -- Recipe: Savory Deviate Delight
  6892, -- Recipe: Smoked Bear Meat
  7678, -- Recipe: Thistle Tea
  12226, -- Recipe: Crispy Bat Wing
  12227, -- Recipe: Lean Wolf Steak
  12228, -- Recipe: Roast Raptor
  12229, -- Recipe: Hot Wolf Ribs
  12231, -- Recipe: Jungle Stew
  12232, -- Recipe: Carrion Surprise
  12233, -- Recipe: Mystery Stew
  12239, -- Recipe: Dragonbreath Chili
  12240, -- Recipe: Heavy Kodo Stew
  13939, -- Recipe: Spotted Yellowtail
  13940, -- Recipe: Cooked Glossy Mightfish
  13941, -- Recipe: Filet of Redgill
  13942, -- Recipe: Grilled Squid
  13943, -- Recipe: Hot Smoked Bass
  13945, -- Recipe: Nightfin Soup
  13946, -- Recipe: Poached Sunscale Salmon
  13947, -- Recipe: Lobster Stew
  13948, -- Recipe: Mightfish Steak
  13949, -- Recipe: Baked Salmon
  16072, -- Expert Cookbook
  16110, -- Recipe: Monster Omelet
  16111, -- Recipe: Spiced Chili Crab
  16767, -- Recipe: Undermine Clam Chowder
  17062, -- Recipe: Mithril Head Trout
  17200, -- Recipe: Gingerbread Cookie
  17201, -- Recipe: Winter Veil Egg Nog
  18046, -- Recipe: Tender Wolf Steak
  18160, -- Recipe: Thistle Tea
  18267, -- Recipe: Runn Tum Tuber Surprise
  20075, -- Recipe: Heavy Crocolisk Stew
  21025, -- Recipe: Dirge's Kickin' Chimaerok Chops
  21099, -- Recipe: Smoked Sagefish
  21219, -- Recipe: Sagefish Delight
}

-- Enchanting Recipes
database["EnchantingRecipes"] = {
  6342, -- Formula: Enchant Chest - Minor Mana
  6344, -- Formula: Enchant Bracer - Minor Versatility
  6346, -- Formula: Enchant Chest - Lesser Mana
  6347, -- Formula: Enchant Bracer - Minor Strength
  6348, -- Formula: Enchant Weapon - Minor Beastslayer
  6349, -- Formula: Enchant 2H Weapon - Lesser Intellect
  6375, -- Formula: Enchant Bracer - Lesser Versatility
  6377, -- Formula: Enchant Boots - Minor Agility
  11038, -- Formula: Enchant 2H Weapon - Lesser Versatility
  11039, -- Formula: Enchant Cloak - Minor Agility
  11081, -- Formula: Enchant Shield - Lesser Protection
  11101, -- Formula: Enchant Bracer - Lesser Strength
  11150, -- Formula: Enchant Gloves - Mining
  11151, -- Ancient Enchanting Vellum
  11152, -- Formula: Enchant Gloves - Fishing
  11163, -- Formula: Enchant Bracer - Lesser Dodge
  11164, -- Formula: Enchant Weapon - Lesser Beastslayer
  11165, -- Formula: Enchant Weapon - Lesser Elemental Slayer
  11166, -- Formula: Enchant Gloves - Skinning
  11167, -- Formula: Enchant Boots - Lesser Versatility
  11168, -- Formula: Enchant Shield - Lesser Parry
  11202, -- Formula: Enchant Shield - Stamina
  11203, -- Formula: Enchant Gloves - Advanced Mining
  11204, -- Formula: Enchant Bracer - Greater Versatility
  11205, -- Formula: Enchant Gloves - Advanced Herbalism
  11206, -- Formula: Enchant Cloak - Lesser Agility
  11207, -- Formula: Enchant Weapon - Fiery Weapon
  11208, -- Formula: Enchant Weapon - Demonslaying
  11223, -- Formula: Enchant Bracer - Dodge
  11225, -- Formula: Enchant Bracer - Greater Stamina
  11226, -- Formula: Enchant Gloves - Riding Skill
  11813, -- Formula: Smoking Heart of the Mountain
  16214, -- Formula: Enchant Bracer - Greater Intellect
  16215, -- Formula: Enchant Boots - Greater Stamina
  16217, -- Formula: Enchant Shield - Greater Stamina
  16218, -- Formula: Enchant Bracer - Superior Versatility
  16219, -- Formula: Enchant Gloves - Greater Agility
  16220, -- Formula: Enchant Boots - Versatility
  16221, -- Formula: Enchant Chest - Major Health
  16222, -- Formula: Enchant Shield - Vitality
  16223, -- Formula: Enchant Weapon - Icy Chill
  16224, -- Formula: Enchant Cloak - Superior Defense
  16242, -- Formula: Enchant Chest - Major Mana
  16244, -- Formula: Enchant Gloves - Greater Strength
  16245, -- Formula: Enchant Boots - Greater Agility
  16246, -- Formula: Enchant Bracer - Superior Strength
  16247, -- Formula: Enchant 2H Weapon - Superior Impact
  16248, -- Formula: Enchant Weapon - Unholy
  16249, -- Formula: Enchant 2H Weapon - Major Intellect
  16250, -- Formula: Enchant Weapon - Superior Striking
  16251, -- Formula: Enchant Bracer - Superior Stamina
  16252, -- Formula: Enchant Weapon - Crusader
  16253, -- Formula: Enchant Chest - Greater Stats
  16254, -- Formula: Enchant Weapon - Lifestealing
  16255, -- Formula: Enchant 2H Weapon - Major Versatility
  17725, -- Formula: Enchant Weapon - Winter's Might
  18259, -- Formula: Enchant Weapon - Spellpower
  18260, -- Formula: Enchant Weapon - Healing Power
  19444, -- Formula: Enchant Weapon - Strength
  19445, -- Formula: Enchant Weapon - Agility
  19446, -- Formula: Enchant Bracer - Argent Versatility
  19447, -- Formula: Enchant Bracer - Healing Power
  19448, -- Formula: Enchant Weapon - Mighty Versatility
  19449, -- Formula: Enchant Weapon - Mighty Intellect
  20726, -- Formula: Enchant Gloves - Threat
  20727, -- Formula: Enchant Gloves - Shadow Power
  20728, -- Formula: Enchant Gloves - Frost Power
  20729, -- Formula: Enchant Gloves - Fire Power
  20730, -- Formula: Enchant Gloves - Healing Power
  20731, -- Formula: Enchant Gloves - Superior Agility
  20734, -- Formula: Enchant Cloak - Stealth
  20735, -- Formula: Enchant Cloak - Subtlety
  20736, -- Formula: Enchant Cloak - Dodge
  20752, -- Formula: Minor Mana Oil
  20753, -- Formula: Lesser Wizard Oil
  20754, -- Formula: Lesser Mana Oil
  20755, -- Formula: Wizard Oil
  20756, -- Formula: Brilliant Wizard Oil
  20757, -- Formula: Brilliant Mana Oil
  20758, -- Formula: Minor Wizard Oil
  22392, -- Formula: Enchant 2H Weapon - Agility
}

-- Engineering Recipes
database["EngineeringRecipes"] = {
  4408, -- Schematic: Mechanical Squirrel Box
  4409, -- Schematic: Small Seaforium Charge
  4410, -- Schematic: Shadow Goggles
  4411, -- Schematic: Flame Deflector
  4412, -- Schematic: Moonsight Rifle
  4413, -- Schematic: Discombobulator Ray
  4414, -- Schematic: Portable Bronze Mortar
  4415, -- Schematic: Craftsman's Monocle
  4416, -- Schematic: Goblin Land Mine
  4417, -- Schematic: Large Seaforium Charge
  6672, -- Schematic: Flash Bomb
  6716, -- Schematic: EZ-Thro Dynamite
  7560, -- Schematic: Gnomish Universal Remote
  7561, -- Schematic: Goblin Jumper Cables
  7742, -- Schematic: Gnomish Cloaking Device
  10601, -- Schematic: Bright-Eye Goggles
  10602, -- Schematic: Deadly Scope
  10603, -- Schematic: Catseye Ultra Goggles
  10604, -- Schematic: Mithril Heavy-Bore Rifle
  10605, -- Schematic: Spellpower Goggles Xtreme
  10606, -- Schematic: Parachute Cloak
  10607, -- Schematic: Deepdive Helmet
  10608, -- Schematic: Sniper Scope
  10609, -- Schematic: Mithril Mechanical Dragonling
  11827, -- Schematic: Lil' Smoky
  11828, -- Schematic: Pet Bombling
  13308, -- Schematic: Ice Deflector
  13309, -- Schematic: Lovingly Crafted Boomstick
  13310, -- Schematic: Accurate Scope
  13311, -- Schematic: Mechanical Dragonling
  14639, -- Schematic: Minor Recombobulator
  16041, -- Schematic: Thorium Grenade
  16042, -- Schematic: Thorium Widget
  16043, -- Schematic: Thorium Rifle
  16044, -- Schematic: Lifelike Mechanical Toad
  16045, -- Schematic: Spellpower Goggles Xtreme Plus
  16046, -- Schematic: Masterwork Target Dummy
  16047, -- Schematic: Thorium Tube
  16048, -- Schematic: Dark Iron Rifle
  16049, -- Schematic: Dark Iron Bomb
  16050, -- Schematic: Delicate Arcanite Converter
  16052, -- Schematic: Voice Amplification Modulator
  16053, -- Schematic: Master Engineer's Goggles
  16054, -- Schematic: Arcanite Dragonling
  16055, -- Schematic: Arcane Bomb
  16056, -- Schematic: Flawless Arcanite Rifle
  17720, -- Schematic: Snowmaster 9000
  18290, -- Schematic: Biznicks 247x128 Accurascope
  18291, -- Schematic: Force Reactive Disk
  18292, -- Schematic: Core Marksman Rifle
  18647, -- Schematic: Red Firework
  18648, -- Schematic: Green Firework
  18649, -- Schematic: Blue Firework
  18650, -- Schematic: EZ-Thro Dynamite II
  18651, -- Schematic: Truesilver Transformer
  18652, -- Schematic: Gyrofreeze Ice Reflector
  18653, -- Schematic: Goblin Jumper Cables XL
  18654, -- Schematic: Gnomish Alarm-o-Bot
  18655, -- Schematic: Major Recombobulator
  18656, -- Schematic: Powerful Seaforium Charge
  18657, -- Schematic: Hyper-Radiant Flame Reflector
  18658, -- Schematic: Ultra-Flash Shadow Reflector
  18661, -- Schematic: World Enlarger
  19027, -- Schematic: Snake Burst Firework
  20000, -- Schematic: Bloodvine Goggles
  20001, -- Schematic: Bloodvine Lens
  21728, -- Schematic: Large Green Rocket
  21729, -- Schematic: Large Red Rocket
  21733, -- Schematic: Large Blue Rocket Cluster
  21734, -- Schematic: Large Green Rocket Cluster
  21735, -- Schematic: Large Red Rocket Cluster
  21737, -- Schematic: Cluster Launcher
  21738, -- Schematic: Firework Launcher
}

-- Fishing Recipes
database["FishingRecipes"] = {
  16083, -- Expert Fishing - The Bass and You
}

-- Leatherworking Recipes
database["LeatherworkingRecipes"] = {
  2406, -- Pattern: Fine Leather Boots
  2407, -- Pattern: White Leather Jerkin
  2408, -- Pattern: Fine Leather Gloves
  2409, -- Pattern: Dark Leather Tunic
  4293, -- Pattern: Hillman's Leather Vest
  4294, -- Pattern: Hillman's Belt
  4296, -- Pattern: Dark Leather Shoulders
  4297, -- Pattern: Barbaric Gloves
  4298, -- Pattern: Guardian Belt
  4299, -- Pattern: Guardian Armor
  4300, -- Pattern: Guardian Leather Bracers
  4301, -- Pattern: Barbaric Belt
  5083, -- Pattern: Kodo Hide Bag
  5786, -- Pattern: Murloc Scale Belt
  5787, -- Pattern: Murloc Scale Breastplate
  5788, -- Pattern: Thick Murloc Armor
  5789, -- Pattern: Murloc Scale Bracers
  5972, -- Pattern: Fine Leather Pants
  5973, -- Pattern: Barbaric Leggings
  5974, -- Pattern: Guardian Cloak
  6474, -- Pattern: Deviate Scale Cloak
  6475, -- Pattern: Deviate Scale Gloves
  6476, -- Pattern: Deviate Scale Belt
  6710, -- Pattern: Moonglow Vest
  7288, -- Pattern: Rugged Leather Pants
  7289, -- Pattern: Black Whelp Cloak
  7290, -- Pattern: Red Whelp Gloves
  7360, -- Pattern: Dark Leather Gloves
  7361, -- Pattern: Herbalist's Gloves
  7362, -- Pattern: Earthen Leather Shoulders
  7363, -- Pattern: Pilferer's Gloves
  7364, -- Pattern: Heavy Earthen Gloves
  7449, -- Pattern: Dusky Leather Leggings
  7450, -- Pattern: Green Whelp Armor
  7451, -- Pattern: Green Whelp Bracers
  7452, -- Pattern: Dusky Boots
  7453, -- Pattern: Swift Boots
  7613, -- Pattern: Green Leather Armor
  8384, -- Pattern: Comfortable Leather Hat
  8385, -- Pattern: Turtle Scale Gloves
  8386, -- Pattern: Big Voodoo Robe
  8387, -- Pattern: Big Voodoo Mask
  8389, -- Pattern: Big Voodoo Pants
  8390, -- Pattern: Big Voodoo Cloak
  8395, -- Pattern: Tough Scorpid Breastplate
  8397, -- Pattern: Tough Scorpid Bracers
  8398, -- Pattern: Tough Scorpid Gloves
  8399, -- Pattern: Tough Scorpid Boots
  8400, -- Pattern: Tough Scorpid Shoulders
  8401, -- Pattern: Tough Scorpid Leggings
  8402, -- Pattern: Tough Scorpid Helm
  8403, -- Pattern: Wild Leather Shoulders
  8404, -- Pattern: Wild Leather Vest
  8405, -- Pattern: Wild Leather Helmet
  8406, -- Pattern: Wild Leather Boots
  8407, -- Pattern: Wild Leather Leggings
  8408, -- Pattern: Wild Leather Cloak
  8409, -- Pattern: Nightscape Shoulders
  13287, -- Pattern: Raptor Hide Harness
  13288, -- Pattern: Raptor Hide Belt
  14635, -- Pattern: Gem-Studded Leather Belt
  15724, -- Pattern: Heavy Scorpid Bracers
  15725, -- Pattern: Wicked Leather Gauntlets
  15726, -- Pattern: Green Dragonscale Breastplate
  15727, -- Pattern: Heavy Scorpid Vest
  15728, -- Pattern: Wicked Leather Bracers
  15729, -- Pattern: Chimeric Gloves
  15730, -- Pattern: Red Dragonscale Breastplate
  15731, -- Pattern: Runic Leather Gauntlets
  15732, -- Pattern: Volcanic Leggings
  15733, -- Pattern: Green Dragonscale Leggings
  15734, -- Pattern: Living Shoulders
  15735, -- Pattern: Ironfeather Shoulders
  15737, -- Pattern: Chimeric Boots
  15738, -- Pattern: Heavy Scorpid Gauntlets
  15739, -- Pattern: Runic Leather Bracers
  15740, -- Pattern: Frostsaber Boots
  15741, -- Pattern: Stormshroud Pants
  15742, -- Pattern: Warbear Harness
  15743, -- Pattern: Heavy Scorpid Belt
  15744, -- Pattern: Wicked Leather Headband
  15745, -- Pattern: Runic Leather Belt
  15746, -- Pattern: Chimeric Leggings
  15747, -- Pattern: Frostsaber Leggings
  15748, -- Pattern: Heavy Scorpid Leggings
  15749, -- Pattern: Volcanic Breastplate
  15751, -- Pattern: Blue Dragonscale Breastplate
  15752, -- Pattern: Living Leggings
  15753, -- Pattern: Stormshroud Armor
  15754, -- Pattern: Warbear Woolies
  15755, -- Pattern: Chimeric Vest
  15756, -- Pattern: Runic Leather Headband
  15757, -- Pattern: Wicked Leather Pants
  15758, -- Pattern: Devilsaur Gauntlets
  15759, -- Pattern: Black Dragonscale Breastplate
  15760, -- Pattern: Ironfeather Breastplate
  15761, -- Pattern: Frostsaber Gloves
  15762, -- Pattern: Heavy Scorpid Helm
  15763, -- Pattern: Blue Dragonscale Shoulders
  15764, -- Pattern: Stormshroud Shoulders
  15765, -- Pattern: Runic Leather Pants
  15768, -- Pattern: Wicked Leather Belt
  15770, -- Pattern: Black Dragonscale Shoulders
  15771, -- Pattern: Living Breastplate
  15772, -- Pattern: Devilsaur Leggings
  15773, -- Pattern: Wicked Leather Armor
  15774, -- Pattern: Heavy Scorpid Shoulders
  15775, -- Pattern: Volcanic Shoulders
  15776, -- Pattern: Runic Leather Armor
  15777, -- Pattern: Runic Leather Shoulders
  15779, -- Pattern: Frostsaber Tunic
  15781, -- Pattern: Black Dragonscale Leggings
  17022, -- Pattern: Corehound Boots
  17023, -- Pattern: Molten Helm
  17025, -- Pattern: Black Dragonscale Boots
  17722, -- Pattern: Gloves of the Greatfather
  18239, -- Pattern: Shadowskin Gloves
  18252, -- Pattern: Core Armor Kit
  18514, -- Pattern: Girdle of Insight
  18515, -- Pattern: Mongoose Boots
  18516, -- Pattern: Swift Flight Bracers
  18517, -- Pattern: Chromatic Cloak
  18518, -- Pattern: Hide of the Wild
  18519, -- Pattern: Shifting Cloak
  18731, -- Pattern: Heavy Leather Ball
  18949, -- Pattern: Barbaric Bracers
  19326, -- Pattern: Might of the Timbermaw
  19327, -- Pattern: Timbermaw Brawlers
  19328, -- Pattern: Dawn Treaders
  19329, -- Pattern: Golden Mantle of the Dawn
  19330, -- Pattern: Lava Belt
  19331, -- Pattern: Chromatic Gauntlets
  19332, -- Pattern: Corehound Belt
  19333, -- Pattern: Molten Belt
  19769, -- Pattern: Primal Batskin Jerkin
  19770, -- Pattern: Primal Batskin Gloves
  19771, -- Pattern: Primal Batskin Bracers
  19772, -- Pattern: Blood Tiger Breastplate
  19773, -- Pattern: Blood Tiger Shoulders
  20253, -- Pattern: Warbear Harness
  20254, -- Pattern: Warbear Woolies
  20382, -- Pattern: Dreamscale Breastplate
  20506, -- Pattern: Spitfire Bracers
  20507, -- Pattern: Spitfire Gauntlets
  20508, -- Pattern: Spitfire Breastplate
  20509, -- Pattern: Sandstalker Bracers
  20510, -- Pattern: Sandstalker Gauntlets
  20511, -- Pattern: Sandstalker Breastplate
  20576, -- Pattern: Black Whelp Tunic
  21548, -- Pattern: Stormshroud Gloves
  22769, -- Pattern: Bramblewood Belt
  22770, -- Pattern: Bramblewood Boots
  22771, -- Pattern: Bramblewood Helm
}

-- Tailoring Recipes
database["TailoringRecipes"] = {
  2598, -- Pattern: Red Linen Robe
  2601, -- Pattern: Gray Woolen Robe
  4292, -- Pattern: Green Woolen Bag
  4345, -- Pattern: Red Woolen Boots
  4346, -- Pattern: Heavy Woolen Cloak
  4347, -- Pattern: Reinforced Woolen Shoulders
  4348, -- Pattern: Phoenix Gloves
  4349, -- Pattern: Phoenix Pants
  4350, -- Pattern: Spider Silk Slippers
  4351, -- Pattern: Shadow Hood
  4352, -- Pattern: Boots of the Enchanter
  4353, -- Pattern: Spider Belt
  4354, -- Pattern: Rich Purple Silk Shirt
  4355, -- Pattern: Icy Cloak
  4356, -- Pattern: Star Belt
  5771, -- Pattern: Red Linen Bag
  5772, -- Pattern: Red Woolen Bag
  5773, -- Pattern: Robes of Arcana
  5774, -- Pattern: Green Silk Pack
  5775, -- Pattern: Black Silk Pack
  6270, -- Pattern: Blue Linen Vest
  6271, -- Pattern: Red Linen Vest
  6272, -- Pattern: Blue Linen Robe
  6274, -- Pattern: Blue Overalls
  6275, -- Pattern: Greater Adept's Robe
  6390, -- Pattern: Stylish Blue Shirt
  6391, -- Pattern: Stylish Green Shirt
  6401, -- Pattern: Dark Silk Shirt
  7084, -- Pattern: Crimson Silk Shoulders
  7085, -- Pattern: Azure Shoulders
  7086, -- Pattern: Earthen Silk Belt
  7087, -- Pattern: Crimson Silk Cloak
  7088, -- Pattern: Crimson Silk Robe
  7089, -- Pattern: Azure Silk Cloak
  7090, -- Pattern: Green Silk Armor
  7091, -- Pattern: Truefaith Gloves
  7092, -- Pattern: Hands of Darkness
  7114, -- Pattern: Azure Silk Gloves
  10300, -- Pattern: Red Mageweave Vest
  10301, -- Pattern: White Bandit Mask
  10302, -- Pattern: Red Mageweave Pants
  10311, -- Pattern: Orange Martial Shirt
  10312, -- Pattern: Red Mageweave Gloves
  10314, -- Pattern: Lavender Mageweave Shirt
  10315, -- Pattern: Red Mageweave Shoulders
  10316, -- Pattern: Colorful Kilt
  10317, -- Pattern: Pink Mageweave Shirt
  10318, -- Pattern: Admiral's Hat
  10320, -- Pattern: Red Mageweave Headband
  10321, -- Pattern: Tuxedo Shirt
  10323, -- Pattern: Tuxedo Pants
  10325, -- Pattern: White Wedding Dress
  10326, -- Pattern: Tuxedo Jacket
  10463, -- Pattern: Shadoweave Mask
  10728, -- Pattern: Black Swashbuckler's Shirt
  14466, -- Pattern: Frostweave Tunic
  14467, -- Pattern: Frostweave Robe
  14468, -- Pattern: Runecloth Bag
  14470, -- Pattern: Runecloth Tunic
  14471, -- Pattern: Cindercloth Vest
  14472, -- Pattern: Runecloth Cloak
  14473, -- Pattern: Ghostweave Belt
  14474, -- Pattern: Frostweave Gloves
  14476, -- Pattern: Cindercloth Gloves
  14477, -- Pattern: Ghostweave Gloves
  14478, -- Pattern: Brightcloth Robe
  14479, -- Pattern: Brightcloth Gloves
  14481, -- Pattern: Runecloth Gloves
  14482, -- Pattern: Cindercloth Cloak
  14483, -- Pattern: Felcloth Pants
  14484, -- Pattern: Brightcloth Cloak
  14485, -- Pattern: Wizardweave Leggings
  14486, -- Pattern: Cloak of Fire
  14488, -- Pattern: Runecloth Boots
  14489, -- Pattern: Frostweave Pants
  14490, -- Pattern: Cindercloth Pants
  14491, -- Pattern: Runecloth Pants
  14492, -- Pattern: Felcloth Boots
  14493, -- Pattern: Robe of Winter Night
  14494, -- Pattern: Brightcloth Pants
  14495, -- ERROR1
  14496, -- Pattern: Felcloth Hood
  14497, -- Pattern: Mooncloth Leggings
  14498, -- Pattern: Runecloth Headband
  14499, -- Pattern: Mooncloth Bag
  14500, -- Pattern: Wizardweave Robe
  14501, -- Pattern: Mooncloth Vest
  14504, -- Pattern: Runecloth Shoulders
  14505, -- Pattern: Wizardweave Turban
  14506, -- Pattern: Felcloth Robe
  14507, -- Pattern: Mooncloth Shoulders
  14508, -- Pattern: Felcloth Shoulders
  14509, -- Pattern: Mooncloth Circlet
  14510, -- Pattern: Bottomless Bag
  14511, -- Pattern: Gloves of Spell Mastery
  14512, -- Pattern: Truefaith Vestments
  14513, -- Pattern: Robe of the Archmage
  14514, -- Pattern: Robe of the Void
  14526, -- Pattern: Mooncloth
  14627, -- Pattern: Bright Yellow Shirt
  14630, -- Pattern: Enchanter's Cowl
  16112, -- Manual: Heavy Silk Bandage
  16113, -- Manual: Mageweave Bandage
  17017, -- Pattern: Flarecore Mantle
  17018, -- Pattern: Flarecore Gloves
  17724, -- Pattern: Green Holiday Shirt
  18265, -- Pattern: Flarecore Wraps
  18414, -- Pattern: Belt of the Archmage
  18415, -- Pattern: Felcloth Gloves
  18416, -- Pattern: Inferno Gloves
  18417, -- Pattern: Mooncloth Gloves
  18418, -- Pattern: Cloak of Warding
  18487, -- Pattern: Mooncloth Robe
  19215, -- Pattern: Wisdom of the Timbermaw
  19216, -- Pattern: Argent Boots
  19217, -- Pattern: Argent Shoulders
  19218, -- Pattern: Mantle of the Timbermaw
  19219, -- Pattern: Flarecore Robe
  19220, -- Pattern: Flarecore Leggings
  19764, -- Pattern: Bloodvine Vest
  19765, -- Pattern: Bloodvine Leggings
  19766, -- Pattern: Bloodvine Boots
  20546, -- Pattern: Runed Stygian Leggings
  20547, -- Pattern: Runed Stygian Boots
  20548, -- Pattern: Runed Stygian Belt
  21358, -- Pattern: Soul Pouch
  21371, -- Pattern: Core Felcloth Bag
  21722, -- Pattern: Festival Dress
  21723, -- Pattern: Festival Suit
  22307, -- Pattern: Enchanted Mageweave Pouch
  22308, -- Pattern: Enchanted Runecloth Bag
  22309, -- Pattern: Big Bag of Enchantment
  22310, -- Pattern: Cenarion Herb Bag
  22312, -- Pattern: Satchel of Cenarius
  22683, -- Pattern: Gaea's Embrace
  22772, -- Pattern: Sylvan Shoulders
  22773, -- Pattern: Sylvan Crown
  22774, -- Pattern: Sylvan Vest
}

-- Permanent Enhancements
database["PermanentEnhancements"] = {
  2304, -- Light Armor Kit
  2313, -- Medium Armor Kit
  4265, -- Heavy Armor Kit
  4405, -- Crude Scope
  4406, -- Standard Scope
  4407, -- Accurate Scope
  6041, -- Steel Weapon Chain
  6042, -- Iron Shield Spike
  6043, -- Iron Counterweight
  7967, -- Mithril Shield Spike
  7969, -- Mithril Spurs
  8173, -- Thick Armor Kit
  10546, -- Deadly Scope
  10548, -- Sniper Scope
  12645, -- Thorium Shield Spike
  15564, -- Rugged Armor Kit
  18251, -- Core Armor Kit
  18283, -- Biznicks 247x128 Accurascope
  19971, -- High Test Eternium Fishing Line
}

-- Temporary Enhancements
database["TemporaryEnhancements"] = {
  2862, -- Rough Sharpening Stone
  2863, -- Coarse Sharpening Stone
  2871, -- Heavy Sharpening Stone
  3239, -- Rough Weightstone
  3240, -- Coarse Weightstone
  3241, -- Heavy Weightstone
  3824, -- Shadow Oil
  3829, -- Frost Oil
  6529, -- Shiny Bauble
  6530, -- Nightcrawlers
  6532, -- Bright Baubles
  6533, -- Aquadynamic Fish Attractor
  6811, -- Aquadynamic Fish Lens
  7307, -- Flesh Eating Worm
  7964, -- Solid Sharpening Stone
  7965, -- Solid Weightstone
  12404, -- Dense Sharpening Stone
  12643, -- Dense Weightstone
  18262, -- Elemental Sharpening Stone
  20744, -- Minor Wizard Oil
  20745, -- Minor Mana Oil
  20746, -- Lesser Wizard Oil
  20747, -- Lesser Mana Oil
  20750, -- Wizard Oil
}

-- Cloth
database["Cloth"] = {
  2320, -- Coarse Thread
  2321, -- Fine Thread
  2589, -- Linen Cloth
  2592, -- Wool Cloth
  2996, -- Bolt of Linen Cloth
  2997, -- Bolt of Woolen Cloth
  3182, -- Spider's Silk
  4291, -- Silken Thread
  4305, -- Bolt of Silk Cloth
  4306, -- Silk Cloth
  4337, -- Thick Spider's Silk
  4338, -- Mageweave Cloth
  4339, -- Bolt of Mageweave
  8343, -- Heavy Silken Thread
  10285, -- Shadow Silk
  14047, -- Runecloth
  14048, -- Bolt of Runecloth
  14227, -- Ironweb Spider Silk
  14256, -- Felcloth
  14341, -- Rune Thread
  14342, -- Mooncloth
}

-- Elemental
database["Elemental"] = {
  7067, -- Elemental Earth
  7068, -- Elemental Fire
  7069, -- Elemental Air
  7070, -- Elemental Water
  7075, -- Core of Earth
  7076, -- Essence of Earth
  7077, -- Heart of Fire
  7078, -- Essence of Fire
  7079, -- Globe of Water
  7080, -- Essence of Water
  7081, -- Breath of Wind
  7082, -- Essence of Air
  7972, -- Ichor of Undeath
  10286, -- Heart of the Wild
  12803, -- Living Essence
  12808, -- Essence of Undeath
}

-- Enchanting
database["Enchanting"] = {
  6217, -- Copper Rod
  10938, -- Lesser Magic Essence
  10939, -- Greater Magic Essence
  10940, -- Strange Dust
  14343, -- Small Brilliant Shard
  14344, -- Large Brilliant Shard
  16202, -- Lesser Eternal Essence
  16203, -- Greater Eternal Essence
  16204, -- Light Illusion Dust
}

-- Herbs
database["Herbs"] = {
  765, -- Silverleaf
  785, -- Mageroyal
  2447, -- Peacebloom
  2449, -- Earthroot
  2450, -- Briarthorn
  2452, -- Swiftthistle
  2453, -- Bruiseweed
  3355, -- Wild Steelbloom
  3356, -- Kingsblood
  3357, -- Liferoot
  3358, -- Khadgar's Whisker
  3369, -- Grave Moss
  3818, -- Fadeleaf
  3819, -- Dragon's Teeth
  3820, -- Stranglekelp
  3821, -- Goldthorn
  4625, -- Firebloom
  8153, -- Wildvine
  8831, -- Purple Lotus
  8836, -- Arthas' Tears
  8838, -- Sungrass
  8839, -- Blindweed
  8845, -- Ghost Mushroom
  8846, -- Gromsblood
  13463, -- Dreamfoil
  13464, -- Golden Sansam
  13465, -- Mountain Silversage
  13466, -- Sorrowmoss
  13467, -- Icecap
  13468, -- Black Lotus
}

-- Inscription
database["Inscription"] = {
  19227, -- Ace of Beasts
  19230, -- Two of Beasts
  19231, -- Three of Beasts
  19232, -- Four of Beasts
  19233, -- Five of Beasts
  19234, -- Six of Beasts
  19235, -- Seven of Beasts
  19236, -- Eight of Beasts
  19258, -- Ace of Warlords
  19259, -- Two of Warlords
  19260, -- Three of Warlords
  19261, -- Four of Warlords
  19262, -- Five of Warlords
  19263, -- Six of Warlords
  19264, -- Seven of Warlords
  19265, -- Eight of Warlords
  19268, -- Ace of Elementals
  19269, -- Two of Elementals
  19270, -- Three of Elementals
  19271, -- Four of Elementals
  19272, -- Five of Elementals
  19273, -- Six of Elementals
  19274, -- Seven of Elementals
  19275, -- Eight of Elementals
  19276, -- Ace of Portals
  19278, -- Two of Portals
  19279, -- Three of Portals
  19280, -- Four of Portals
  19281, -- Five of Portals
  19282, -- Six of Portals
  19283, -- Seven of Portals
  19284, -- Eight of Portals
}

-- Jewelcrafting
database["Jewelcrafting"] = {
  774, -- Malachite
  818, -- Tigerseye
  1206, -- Moss Agate
  1210, -- Shadowgem
  1529, -- Jade
  1705, -- Lesser Moonstone
  3864, -- Citrine
  5498, -- Small Lustrous Pearl
  5500, -- Iridescent Pearl
  7909, -- Aquamarine
  7910, -- Star Ruby
  7971, -- Black Pearl
  11382, -- Blood of the Mountain
  12361, -- Blue Sapphire
  12363, -- Arcane Crystal
  12364, -- Huge Emerald
  12799, -- Large Opal
  12800, -- Azerothian Diamond
  13926, -- Golden Pearl
  18335, -- Pristine Black Diamond
}

-- Leather
database["Leather"] = {
  783, -- Light Hide
  2318, -- Light Leather
  2319, -- Medium Leather
  2934, -- Ruined Leather Scraps
  4231, -- Cured Light Hide
  4232, -- Medium Hide
  4233, -- Cured Medium Hide
  4234, -- Heavy Leather
  4235, -- Heavy Hide
  4236, -- Cured Heavy Hide
  4289, -- Salt
  4304, -- Thick Leather
  4461, -- Raptor Hide
  5082, -- Thin Kodo Leather
  5116, -- Long Tail Feather
  5784, -- Slimy Murloc Scale
  5785, -- Thick Murloc Scale
  6470, -- Deviate Scale
  6471, -- Perfect Deviate Scale
  7286, -- Black Whelp Scale
  7392, -- Green Whelp Scale
  8150, -- Deeprock Salt
  8154, -- Scorpid Scale
  8165, -- Worn Dragonscale
  8167, -- Turtle Scale
  8168, -- Jet Black Feather
  8169, -- Thick Hide
  8170, -- Rugged Leather
  8171, -- Rugged Hide
  8172, -- Cured Thick Hide
  12810, -- Enchanted Leather
  15407, -- Cured Rugged Hide
  15408, -- Heavy Scorpid Scale
  15409, -- Refined Deeprock Salt
  15410, -- Scale of Onyxia
  15412, -- Green Dragonscale
  15414, -- Red Dragonscale
  15415, -- Blue Dragonscale
  15416, -- Black Dragonscale
  15417, -- Devilsaur Leather
  15419, -- Warbear Leather
  17012, -- Core Leather
}

-- Meat & Fish
database["MeatFish"] = {
  723, -- Goretusk Liver
  729, -- Stringy Vulture Meat
  730, -- Murloc Eye
  731, -- Goretusk Snout
  769, -- Chunk of Boar Meat
  1015, -- Lean Wolf Flank
  1080, -- Tough Condor Meat
  1468, -- Murloc Fin
  2251, -- Gooey Spider Leg
  2665, -- Stormwind Seasoning Herbs
  2672, -- Stringy Wolf Meat
  2673, -- Coyote Meat
  2674, -- Crawler Meat
  2675, -- Crawler Claw
  2677, -- Boar Ribs
  2886, -- Crag Boar Rib
  2924, -- Crocolisk Meat
  3172, -- Boar Intestines
  3173, -- Bear Meat
  3174, -- Spider Ichor
  3404, -- Buzzard Wing
  3667, -- Tender Crocolisk Meat
  3685, -- Raptor Egg
  3712, -- Turtle Meat
  3730, -- Big Bear Meat
  3731, -- Lion Meat
  4603, -- Raw Spotted Yellowtail
  4655, -- Giant Clam Meat
  5465, -- Small Spider Leg
  5466, -- Scorpid Stinger
  5467, -- Kodo Meat
  5468, -- Soft Frenzy Flesh
  5469, -- Strider Meat
  5470, -- Thunder Lizard Tail
  5471, -- Stag Meat
  5503, -- Clam Meat
  5504, -- Tangy Clam Meat
  6289, -- Raw Longjaw Mud Snapper
  6291, -- Raw Brilliant Smallfish
  6303, -- Raw Slitherskin Mackerel
  6308, -- Raw Bristle Whisker Catfish
  6317, -- Raw Loch Frenzy
  6361, -- Raw Rainbow Fin Albacore
  6362, -- Raw Rockscale Cod
  6889, -- Small Egg
  7974, -- Zesty Clam Meat
  8365, -- Raw Mithril Head Trout
  8959, -- Raw Spinefin Halibut
  12037, -- Mystery Meat
  12184, -- Raptor Flesh
  12202, -- Tiger Meat
  12203, -- Red Wolf Meat
  12204, -- Heavy Kodo Meat
  12205, -- White Spider Meat
  12206, -- Tender Crab Meat
  12207, -- Giant Egg
  12208, -- Tender Wolf Meat
  12223, -- Meaty Bat Wing
  13754, -- Raw Glossy Mightfish
  13756, -- Raw Summer Bass
  13758, -- Raw Redgill
  13759, -- Raw Nightfin Snapper
  13760, -- Raw Sunscale Salmon
  13888, -- Darkclaw Lobster
  13889, -- Raw Whitescale Salmon
  20424, -- Sandworm Meat
  21024, -- Chimaerok Tenderloin
  21071, -- Raw Sagefish
  21153, -- Raw Greater Sagefish
}

-- Metal & Stone
database["MetalStone"] = {
  2770, -- Copper Ore
  2771, -- Tin Ore
  2772, -- Iron Ore
  2775, -- Silver Ore
  2776, -- Gold Ore
  2835, -- Rough Stone
  2836, -- Coarse Stone
  2838, -- Heavy Stone
  2840, -- Copper Bar
  2841, -- Bronze Bar
  2842, -- Silver Bar
  3470, -- Rough Grinding Stone
  3478, -- Coarse Grinding Stone
  3486, -- Heavy Grinding Stone
  3575, -- Iron Bar
  3576, -- Tin Bar
  3577, -- Gold Bar
  3857, -- Coal
  3858, -- Mithril Ore
  3859, -- Steel Bar
  3860, -- Mithril Bar
  6037, -- Truesilver Bar
  7911, -- Truesilver Ore
  7912, -- Solid Stone
  7966, -- Solid Grinding Stone
  10620, -- Thorium Ore
  11370, -- Dark Iron Ore
  11371, -- Dark Iron Bar
  12359, -- Thorium Bar
  12360, -- Arcanite Bar
  12365, -- Dense Stone
  12644, -- Dense Grinding Stone
  12655, -- Enchanted Thorium Bar
  12809, -- Guardian Stone
  17203, -- Sulfuron Ingot
  17771, -- Enchanted Elementium Bar
  18562, -- Elementium Ingot
  18567, -- Elemental Flux
  22202, -- Small Obsidian Shard
  22203, -- Large Obsidian Shard
}

-- Other Tradegoods
database["OtherTradegoods"] = {
  1288, -- Large Venom Sac
  1475, -- Small Venom Sac
  2324, -- Bleach
  2325, -- Black Dye
  2604, -- Red Dye
  2605, -- Green Dye
  2678, -- Mild Spices
  2880, -- Weak Flux
  3164, -- Discolored Worg Heart
  3371, -- Crystal Vial
  3372, -- Cracked Vial
  3466, -- Strong Flux
  4340, -- Gray Dye
  4341, -- Yellow Dye
  4342, -- Purple Dye
  4402, -- Small Flame Sac
  4470, -- Simple Wood
  5523, -- Small Barnacled Clam
  5524, -- Thick-Shelled Clam
  5635, -- Sharp Claw
  5637, -- Large Fang
  6260, -- Blue Dye
  6261, -- Orange Dye
  6358, -- Oily Blackmouth
  6359, -- Firefin Snapper
  6370, -- Blackmouth Oil
  6371, -- Fire Oil
  7072, -- Naga Scale
  7973, -- Big-Mouth Clam
  8925, -- Tainted Vial
  9210, -- Ghost Dye
  9262, -- Black Vitriol
  9719, -- Broken Blade of Heroes
  10290, -- Pink Dye
  11291, -- Star Wood
  12662, -- Demonic Rune
  12804, -- Powerful Mojo
  12811, -- Righteous Orb
  13422, -- Stonescale Eel
  13423, -- Stonescale Oil
  13757, -- Lightning Eel
  17010, -- Fiery Core
  17011, -- Lava Core
  17204, -- Eye of Sulfuras
  18240, -- Ogre Tannin
  18256, -- Melted Vial
  19441, -- Huge Venom Sac
  19943, -- Massive Mojo
  20520, -- Dark Rune
}

-- Parts
database["Parts"] = {
  814, -- Flask of Oil
  4357, -- Rough Blasting Powder
  4359, -- Handful of Copper Bolts
  4364, -- Coarse Blasting Powder
  4371, -- Bronze Tube
  4375, -- Whirring Bronze Gizmo
  4377, -- Heavy Blasting Powder
  4382, -- Bronze Framework
  4387, -- Iron Strut
  4389, -- Gyrochronatom
  4399, -- Wooden Stock
  4400, -- Heavy Stock
  4404, -- Silver Contact
  4611, -- Blue Pearl
  7071, -- Iron Buckle
  7191, -- Fused Wiring
  9060, -- Inlaid Mithril Cylinder
  9061, -- Goblin Rocket Fuel
  10505, -- Solid Blasting Powder
  10558, -- Gold Power Core
  10559, -- Mithril Tube
  10560, -- Unstable Trigger
  10561, -- Mithril Casing
  10647, -- Engineer's Ink
  15992, -- Dense Blasting Powder
  15994, -- Thorium Widget
  16000, -- Thorium Tube
  16006, -- Delicate Arcanite Converter
  17056, -- Light Feather
  18631, -- Truesilver Transformer
}

local function converttohex(rgb)
  return string.format("%02x%02x%02x", rgb.r * 255, rgb.g * 255, rgb.b * 255)
end

local function converttorgb(hex, as_table)
  if as_table then
    return {
      r = tonumber("0x" .. strsub(hex, 1, 2)) / 255,
      g = tonumber("0x" .. strsub(hex, 3, 4)) / 255,
      b = tonumber("0x" .. strsub(hex, 5, 6)) / 255,
    }
  else
    -- as 3 values
    return tonumber("0x" .. hex:sub(1, 2)) / 255,
      tonumber("0x" .. hex:sub(3, 4)) / 255,
      tonumber("0x" .. hex:sub(5, 6)) / 255
  end
end


local function formatBagTitle(self, title, hex)
  local prefix = ""
  if self.db.profile.prefixCategories then
    if self.db.profile.prefixCategories == "!CUSTOM" then
      prefix = self.db.profile.customPrefix
    else
      prefix = self.db.profile.prefixCategories
    end
  end
  if self.db.profile.coloredPrefix then
    prefix = "|cff" .. converttohex(self.db.profile.color.prefix) .. prefix .. "|r"
    if self.db.profile.coloredCategories then
      return prefix .. "|cff" .. hex .. title .. "|r"
    else
      return prefix .. title
    end
  else
    if self.db.profile.coloredCategories then
      return prefix .. "|cff" .. hex .. title .. "|r"
    else
      return prefix .. title
    end
  end
end

local function MatchIDs_Init(self)
  wipe(Result)

  if self.db.profile.moveMergedConsumables then
    Result[formatBagTitle(self, L["Consumables"], converttohex(self.db.profile.color.mergedConsumables))] =
      AddToSet(database["Bandages"], database["Consumables"], database["FoodsandDrinks"], database["OtherConsumables"])
  else
    if self.db.profile.moveBandages then
      Result[formatBagTitle(self, L["Bandages"], converttohex(self.db.profile.color.Bandages))] =
        AddToSet(database["Bandages"])
    end
    if self.db.profile.moveConsumables then
      Result[formatBagTitle(self, L["Consumables"], converttohex(self.db.profile.color.Consumables))] =
        AddToSet(database["Consumables"])
    end
    if self.db.profile.moveFoodsandDrinks then
      Result[formatBagTitle(self, L["Foods and Drinks"], converttohex(self.db.profile.color.FoodsandDrinks))] =
        AddToSet(database["FoodsandDrinks"])
    end
    if self.db.profile.moveOtherConsumables then
      Result[formatBagTitle(self, L["Other Consumables"], converttohex(self.db.profile.color.OtherConsumables))] =
        AddToSet(database["OtherConsumables"])
    end
  end
  if self.db.profile.moveMergedFlasksElixirsPotions then
    Result[formatBagTitle(
      self,
      L["Flasks, Elixirs & Potions"],
      converttohex(self.db.profile.color.mergedFlasksElixirsPotions)
    )] =
      AddToSet(database["Elixirs"], database["Flasks"], database["Potions"])
  else
    if self.db.profile.moveElixirs then
      Result[formatBagTitle(self, L["Elixirs"], converttohex(self.db.profile.color.Elixirs))] =
        AddToSet(database["Elixirs"])
    end
    if self.db.profile.moveFlasks then
      Result[formatBagTitle(self, L["Flasks"], converttohex(self.db.profile.color.Flasks))] =
        AddToSet(database["Flasks"])
    end
    if self.db.profile.movePotions then
      Result[formatBagTitle(self, L["Potions"], converttohex(self.db.profile.color.Potions))] =
        AddToSet(database["Potions"])
    end
  end
  if self.db.profile.moveHealthstone then
    Result[formatBagTitle(self, L["Healthstone"], converttohex(self.db.profile.color.Healthstone))] =
      AddToSet(database["Healthstone"])
  end
  if self.db.profile.moveMergedRecipes then
    Result[formatBagTitle(self, L["Recipes"], converttohex(self.db.profile.color.mergedRecipes))] = AddToSet(
      database["AlchemyRecipes"],
      database["BlacksmithingRecipes"],
      database["CookingRecipes"],
      database["EnchantingRecipes"],
      database["EngineeringRecipes"],
      database["FishingRecipes"],
      database["LeatherworkingRecipes"],
      database["TailoringRecipes"]
    )
  else
    if self.db.profile.moveAlchemyRecipes then
      Result[formatBagTitle(self, L["Alchemy Recipes"], converttohex(self.db.profile.color.AlchemyRecipes))] =
        AddToSet(database["AlchemyRecipes"])
    end
    if self.db.profile.moveBlacksmithingRecipes then
      Result[formatBagTitle(self, L["Blacksmithing Recipes"], converttohex(self.db.profile.color.BlacksmithingRecipes))] =
        AddToSet(database["BlacksmithingRecipes"])
    end
    if self.db.profile.moveCookingRecipes then
      Result[formatBagTitle(self, L["Cooking Recipes"], converttohex(self.db.profile.color.CookingRecipes))] =
        AddToSet(database["CookingRecipes"])
    end
    if self.db.profile.moveEnchantingRecipes then
      Result[formatBagTitle(self, L["Enchanting Recipes"], converttohex(self.db.profile.color.EnchantingRecipes))] =
        AddToSet(database["EnchantingRecipes"])
    end
    if self.db.profile.moveEngineeringRecipes then
      Result[formatBagTitle(self, L["Engineering Recipes"], converttohex(self.db.profile.color.EngineeringRecipes))] =
        AddToSet(database["EngineeringRecipes"])
    end
    if self.db.profile.moveFishingRecipes then
      Result[formatBagTitle(self, L["Fishing Recipes"], converttohex(self.db.profile.color.FishingRecipes))] =
        AddToSet(database["FishingRecipes"])
    end
    if self.db.profile.moveLeatherworkingRecipes then
      Result[formatBagTitle(
        self,
        L["Leatherworking Recipes"],
        converttohex(self.db.profile.color.LeatherworkingRecipes)
      )] =
        AddToSet(database["LeatherworkingRecipes"])
    end
    if self.db.profile.moveTailoringRecipes then
      Result[formatBagTitle(self, L["Tailoring Recipes"], converttohex(self.db.profile.color.TailoringRecipes))] =
        AddToSet(database["TailoringRecipes"])
    end
  end
  if self.db.profile.moveMergedTemporaryPermanentEnhancements then
    Result[formatBagTitle(
      self,
      L["Temporary & Permanent Enhancements"],
      converttohex(self.db.profile.color.mergedTemporaryPermanentEnhancements)
    )] =
      AddToSet(database["PermanentEnhancements"], database["TemporaryEnhancements"])
  else
    if self.db.profile.movePermanentEnhancements then
      Result[formatBagTitle(
        self,
        L["Permanent Enhancements"],
        converttohex(self.db.profile.color.PermanentEnhancements)
      )] =
        AddToSet(database["PermanentEnhancements"])
    end
    if self.db.profile.moveTemporaryEnhancements then
      Result[formatBagTitle(
        self,
        L["Temporary Enhancements"],
        converttohex(self.db.profile.color.TemporaryEnhancements)
      )] =
        AddToSet(database["TemporaryEnhancements"])
    end
  end
  if self.db.profile.moveMergedTradegoods then
    Result[formatBagTitle(self, L["Tradegoods"], converttohex(self.db.profile.color.mergedTradegoods))] = AddToSet(
      database["Cloth"],
      database["Elemental"],
      database["Enchanting"],
      database["Herbs"],
      database["Inscription"],
      database["Jewelcrafting"],
      database["Leather"],
      database["MeatFish"],
      database["MetalStone"],
      database["OtherTradegoods"],
      database["Parts"]
    )
  else
    if self.db.profile.moveCloth then
      Result[formatBagTitle(self, L["Cloth"], converttohex(self.db.profile.color.Cloth))] = AddToSet(database["Cloth"])
    end
    if self.db.profile.moveElemental then
      Result[formatBagTitle(self, L["Elemental"], converttohex(self.db.profile.color.Elemental))] =
        AddToSet(database["Elemental"])
    end
    if self.db.profile.moveEnchanting then
      Result[formatBagTitle(self, L["Enchanting"], converttohex(self.db.profile.color.Enchanting))] =
        AddToSet(database["Enchanting"])
    end
    if self.db.profile.moveHerbs then
      Result[formatBagTitle(self, L["Herbs"], converttohex(self.db.profile.color.Herbs))] = AddToSet(database["Herbs"])
    end
    if self.db.profile.moveInscription then
      Result[formatBagTitle(self, L["Inscription"], converttohex(self.db.profile.color.Inscription))] =
        AddToSet(database["Inscription"])
    end
    if self.db.profile.moveJewelcrafting then
      Result[formatBagTitle(self, L["Jewelcrafting"], converttohex(self.db.profile.color.Jewelcrafting))] =
        AddToSet(database["Jewelcrafting"])
    end
    if self.db.profile.moveLeather then
      Result[formatBagTitle(self, L["Leather"], converttohex(self.db.profile.color.Leather))] =
        AddToSet(database["Leather"])
    end
    if self.db.profile.moveMeatFish then
      Result[formatBagTitle(self, L["Meat & Fish"], converttohex(self.db.profile.color.MeatFish))] =
        AddToSet(database["MeatFish"])
    end
    if self.db.profile.moveMetalStone then
      Result[formatBagTitle(self, L["Metal & Stone"], converttohex(self.db.profile.color.MetalStone))] =
        AddToSet(database["MetalStone"])
    end
    if self.db.profile.moveOtherTradegoods then
      Result[formatBagTitle(self, L["Other Tradegoods"], converttohex(self.db.profile.color.OtherTradegoods))] =
        AddToSet(database["OtherTradegoods"])
    end
    if self.db.profile.moveParts then
      Result[formatBagTitle(self, L["Parts"], converttohex(self.db.profile.color.Parts))] = AddToSet(database["Parts"])
    end
  end

  return Result
end

local setFilter = AdiBags:RegisterFilter("Classic", 98, "ABEvent-1.0")
setFilter.uiName = string.format("|cffd6ff5a%s|r", L["Classic"])
setFilter.uiDesc =
  string.format("%s\n|cffffd800%s: 1.0.6|r", L["Items from the main game."], L["Filter version"])

function setFilter:OnInitialize()
  self.db = AdiBags.db:RegisterNamespace("Classic", {
    profile = {
      coloredCategories = true,
      prefixCategories = "",
      customPrefix = "",
      coloredPrefix = true,
      moveMergedConsumables = false,
      moveBandages = true,
      moveConsumables = true,
      moveFoodsandDrinks = true,
      moveOtherConsumables = true,
      moveMergedFlasksElixirsPotions = true,
      moveElixirs = true,
      moveFlasks = true,
      movePotions = true,
      moveHealthstone = false,
      moveMergedRecipes = true,
      moveAlchemyRecipes = true,
      moveBlacksmithingRecipes = true,
      moveCookingRecipes = true,
      moveEnchantingRecipes = true,
      moveEngineeringRecipes = true,
      moveFishingRecipes = true,
      moveLeatherworkingRecipes = true,
      moveTailoringRecipes = true,
      moveMergedTemporaryPermanentEnhancements = true,
      movePermanentEnhancements = true,
      moveTemporaryEnhancements = true,
      moveMergedTradegoods = true,
      moveCloth = true,
      moveElemental = true,
      moveEnchanting = true,
      moveHerbs = true,
      moveInscription = true,
      moveJewelcrafting = true,
      moveLeather = true,
      moveMeatFish = true,
      moveMetalStone = true,
      moveOtherTradegoods = true,
      moveParts = true,

      color = {
        prefix = converttorgb("d6ff5a", true),
        mergedConsumables = converttorgb("7aa36f", true),
        Bandages = converttorgb("fff600", true),
        Consumables = converttorgb("49678d", true),
        FoodsandDrinks = converttorgb("9b59b6", true),
        OtherConsumables = converttorgb("4e878c", true),
        mergedFlasksElixirsPotions = converttorgb("769fb6", true),
        Elixirs = converttorgb("689a8c", true),
        Flasks = converttorgb("b60f96", true),
        Potions = converttorgb("9dbbae", true),
        Healthstone = converttorgb("93e5ab", true),
        mergedRecipes = converttorgb("68d080", true),
        AlchemyRecipes = converttorgb("4e9a06", true),
        BlacksmithingRecipes = converttorgb("8f8f8f", true),
        CookingRecipes = converttorgb("e9b96e", true),
        EnchantingRecipes = converttorgb("5c3566", true),
        EngineeringRecipes = converttorgb("c4a000", true),
        FishingRecipes = converttorgb("3465a4", true),
        LeatherworkingRecipes = converttorgb("8b4513", true),
        TailoringRecipes = converttorgb("d3d7cf", true),
        mergedTemporaryPermanentEnhancements = converttorgb("5a7684", true),
        PermanentEnhancements = converttorgb("92afd7", true),
        TemporaryEnhancements = converttorgb("c5d1eb", true),
        mergedTradegoods = converttorgb("786f52", true),
        Cloth = converttorgb("feb95f", true),
        Elemental = converttorgb("c2095a", true),
        Enchanting = converttorgb("540d6e", true),
        Herbs = converttorgb("0ead69", true),
        Inscription = converttorgb("ffd23f", true),
        Jewelcrafting = converttorgb("090446", true),
        Leather = converttorgb("563635", true),
        MeatFish = converttorgb("f71735", true),
        MetalStone = converttorgb("6e9075", true),
        OtherTradegoods = converttorgb("81f0e5", true),
        Parts = converttorgb("5b6057", true),
      },
    },
  })
end

function setFilter:Update()
  MatchIDs = nil
  self:SendMessage("AdiBags_FiltersChanged")
end

function setFilter:OnEnable()
  AdiBags:UpdateFilters()
end

function setFilter:OnDisable()
  AdiBags:UpdateFilters()
end

function setFilter:Filter(slotData)
  MatchIDs = MatchIDs or MatchIDs_Init(self)
  for i, name in pairs(MatchIDs) do
    -- Override Method
    if MatchIDs[i]["override"] then
      slotData["loc"] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
      if slotData["loc"] and slotData["loc"]:IsValid() then
        if MatchIDs[i]["override"](slotData.loc) then
          return i
        end
      end

      -- Bonus Condition (triggers when bonus condition is not fulfilled)
    elseif MatchIDs[i]["bonus_condition"] then
      if name[slotData.itemId] then
        slotData["loc"] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
        if slotData["loc"] and slotData["loc"]:IsValid() then
          if not MatchIDs[i]["bonus_condition"](slotData.loc) then
            -- THERE IS A NOT HERE!
            return i
          end
        end
      end

      -- Standard ID Matching
    elseif name[slotData.itemId] then
      return i
    end
  end
end

function setFilter:GetOptions()
  return {
    general_config = {
      type = "group",
      name = L["General Settings"],
      desc = L["Settings affecting all categories."],
      inline = true,
      order = 1,
      args = {
        description = {
          type = "description",
          name = string.format(
            "%s |cffffd800%s |cff529F00%s|r",
            L["These settings affect all categories of this filter."],
            L["If you overwrite prefix or categorie color, you either need to toggle the color setting twice or reload."],
            L["AdiBags never intended to use icons, so they are glitchy. Make sure to disable prefix color, if you use an icon."]
          ),
          order = 1,
        },
        coloredCategories = {
          name = string.format("|cffFDFD96%s|r", L["Colored Categories"]),
          desc = L["Should Categories be colored?"],
          width = "full",
          type = "toggle",
          order = 10,
        },
        prefixCategories = {
          name = L["Prefix Categories"],
          desc = L["Select a prefix for the categories, if you like."],
          type = "select",
          order = 20,
          values = {
            [""] = L["None"],
            ["!CUSTOM"] = L["Custom Prefix"],
            ["C"] = "C",
            ["C-"] = "C-",
            ["0."] = "0.",
            ["V"] = "V",
            ["V-"] = "V-",
            ["|T4279397:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T4279397:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T1120721:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T1120721:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T626006:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T626006:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T626003:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T626003:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T626008:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T626008:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
          },
        },
        customPrefix = {
          name = L["Custom Prefix"],
          desc = L["Enter a custom prefix for the categories."],
          type = "input",
          order = 30,
          width = "full",
          disabled = function()
            return self.db.profile.prefixCategories ~= "!CUSTOM"
          end,
        },
        coloredPrefix = {
          name = string.format("|cffB9FFB9%s|r", L["Colored Prefix"]),
          desc = L["Should the prefix be colored to the filter color? (Only works for text-prefixes, for obvious reasons.)"],
          type = "toggle",
          order = 40,
        },
        prefixColor = {
          name = L["Prefix Color"],
          desc = L["Select a color for the prefix."],
          type = "color",
          order = 50,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.coloredPrefix
          end,
          get = function()
            local color = self.db.profile.color.prefix
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.prefix
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    Consumables_config = {
      type = "group",
      name = L["Consumables"],
      desc = "", -- doesnt work,
      inline = true,
      order = 52,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Items you can eat or use to improve yourself"],
          order = 53,
        },
        moveMergedConsumables = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Consumables"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Consumables"]),
          type = "toggle",
          width = 1.5,
          order = 54,
        },
        colorMergedConsumables = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["Consumables"]),
          type = "color",
          order = 55,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.mergedConsumables
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedConsumables
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_1 = {
          type = "header",
          name = "",
          order = 56,
        },
        moveBandages = {
          name = L["Bandages"],
          desc = L["Bandages to heal yourself."],
          type = "toggle",
          width = 1.5,
          order = 57,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorBandages = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Bandages"]),
          type = "color",
          order = 58,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Bandages
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Bandages
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_2 = {
          type = "header",
          name = "",
          order = 59,
        },
        moveConsumables = {
          name = L["Consumables"],
          desc = L["Consumables to consume."],
          type = "toggle",
          width = 1.5,
          order = 60,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorConsumables = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Consumables"]),
          type = "color",
          order = 61,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Consumables
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Consumables
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_3 = {
          type = "header",
          name = "",
          order = 62,
        },
        moveFoodsandDrinks = {
          name = L["Foods and Drinks"],
          desc = L["Foods and Drinks to consume."],
          type = "toggle",
          width = 1.5,
          order = 63,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorFoodsandDrinks = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Foods and Drinks"]),
          type = "color",
          order = 64,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.FoodsandDrinks
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.FoodsandDrinks
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_4 = {
          type = "header",
          name = "",
          order = 65,
        },
        moveOtherConsumables = {
          name = L["Other Consumables"],
          desc = L["Other Consumables to consume."],
          type = "toggle",
          width = 1.5,
          order = 66,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorOtherConsumables = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Other Consumables"]),
          type = "color",
          order = 67,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.OtherConsumables
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.OtherConsumables
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    FlasksElixirsPotions_config = {
      type = "group",
      name = L["Flasks, Elixirs & Potions"],
      desc = "", -- doesnt work,
      inline = true,
      order = 68,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Drink this for a powerup!"],
          order = 69,
        },
        moveMergedFlasksElixirsPotions = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Flasks, Elixirs & Potions"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Flasks, Elixirs & Potions"]),
          type = "toggle",
          width = 1.5,
          order = 70,
        },
        colorMergedFlasksElixirsPotions = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["Flasks, Elixirs & Potions"]),
          type = "color",
          order = 71,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedFlasksElixirsPotions
          end,
          get = function()
            local color = self.db.profile.color.mergedFlasksElixirsPotions
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedFlasksElixirsPotions
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_5 = {
          type = "header",
          name = "",
          order = 72,
        },
        moveElixirs = {
          name = L["Elixirs"],
          desc = L["Elixirs to drink."],
          type = "toggle",
          width = 1.5,
          order = 73,
          disabled = function()
            return self.db.profile.moveMergedFlasksElixirsPotions
          end,
        },
        colorElixirs = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Elixirs"]),
          type = "color",
          order = 74,
          disabled = function()
            return self.db.profile.moveMergedFlasksElixirsPotions
          end,
          get = function()
            local color = self.db.profile.color.Elixirs
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Elixirs
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_6 = {
          type = "header",
          name = "",
          order = 75,
        },
        moveFlasks = {
          name = L["Flasks"],
          desc = L["Flasks to drink."],
          type = "toggle",
          width = 1.5,
          order = 76,
          disabled = function()
            return self.db.profile.moveMergedFlasksElixirsPotions
          end,
        },
        colorFlasks = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Flasks"]),
          type = "color",
          order = 77,
          disabled = function()
            return self.db.profile.moveMergedFlasksElixirsPotions
          end,
          get = function()
            local color = self.db.profile.color.Flasks
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Flasks
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_7 = {
          type = "header",
          name = "",
          order = 78,
        },
        movePotions = {
          name = L["Potions"],
          desc = L["Potions to drink."],
          type = "toggle",
          width = 1.5,
          order = 79,
          disabled = function()
            return self.db.profile.moveMergedFlasksElixirsPotions
          end,
        },
        colorPotions = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Potions"]),
          type = "color",
          order = 80,
          disabled = function()
            return self.db.profile.moveMergedFlasksElixirsPotions
          end,
          get = function()
            local color = self.db.profile.color.Potions
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Potions
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    Healthstone_config = {
      type = "group",
      name = L["Healthstone"],
      desc = "", -- doesnt work,
      inline = true,
      order = 81,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Just a healthstone."],
          order = 82,
        },
        moveHealthstone = {
          name = L["Healthstone"],
          desc = L["Just your typical healthstone."],
          type = "toggle",
          width = 1.5,
          order = 83,
        },
        colorHealthstone = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Healthstone"]),
          type = "color",
          order = 84,
          disabled = function()
            return self.db.profile.moveMergedHealthstone
          end,
          get = function()
            local color = self.db.profile.color.Healthstone
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Healthstone
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    Recipes_config = {
      type = "group",
      name = L["Recipes"],
      desc = "", -- doesnt work,
      inline = true,
      order = 85,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Recipes for all professions."],
          order = 86,
        },
        moveMergedRecipes = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Recipes"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Recipes"]),
          type = "toggle",
          width = 1.5,
          order = 87,
        },
        colorMergedRecipes = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["Recipes"]),
          type = "color",
          order = 88,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedRecipes
          end,
          get = function()
            local color = self.db.profile.color.mergedRecipes
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedRecipes
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_8 = {
          type = "header",
          name = "",
          order = 89,
        },
        moveAlchemyRecipes = {
          name = L["Alchemy Recipes"],
          desc = L["Recipes for crafting potions, elixirs, and transmuting materials."],
          type = "toggle",
          width = 1.5,
          order = 90,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
        },
        colorAlchemyRecipes = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Alchemy Recipes"]),
          type = "color",
          order = 91,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
          get = function()
            local color = self.db.profile.color.AlchemyRecipes
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.AlchemyRecipes
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_9 = {
          type = "header",
          name = "",
          order = 92,
        },
        moveBlacksmithingRecipes = {
          name = L["Blacksmithing Recipes"],
          desc = L["Recipes for forging metal armor, weapons, and enhancements."],
          type = "toggle",
          width = 1.5,
          order = 93,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
        },
        colorBlacksmithingRecipes = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Blacksmithing Recipes"]),
          type = "color",
          order = 94,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
          get = function()
            local color = self.db.profile.color.BlacksmithingRecipes
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.BlacksmithingRecipes
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_10 = {
          type = "header",
          name = "",
          order = 95,
        },
        moveCookingRecipes = {
          name = L["Cooking Recipes"],
          desc = L["Recipes for preparing food that provides buffs."],
          type = "toggle",
          width = 1.5,
          order = 96,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
        },
        colorCookingRecipes = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Cooking Recipes"]),
          type = "color",
          order = 97,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
          get = function()
            local color = self.db.profile.color.CookingRecipes
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.CookingRecipes
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_11 = {
          type = "header",
          name = "",
          order = 98,
        },
        moveEnchantingRecipes = {
          name = L["Enchanting Recipes"],
          desc = L["Recipes for enchanting gear with magical properties."],
          type = "toggle",
          width = 1.5,
          order = 99,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
        },
        colorEnchantingRecipes = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Enchanting Recipes"]),
          type = "color",
          order = 100,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
          get = function()
            local color = self.db.profile.color.EnchantingRecipes
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.EnchantingRecipes
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_12 = {
          type = "header",
          name = "",
          order = 101,
        },
        moveEngineeringRecipes = {
          name = L["Engineering Recipes"],
          desc = L["Recipes for creating gadgets, explosives, and mechanical devices."],
          type = "toggle",
          width = 1.5,
          order = 102,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
        },
        colorEngineeringRecipes = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Engineering Recipes"]),
          type = "color",
          order = 103,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
          get = function()
            local color = self.db.profile.color.EngineeringRecipes
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.EngineeringRecipes
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_13 = {
          type = "header",
          name = "",
          order = 104,
        },
        moveFishingRecipes = {
          name = L["Fishing Recipes"],
          desc = L["Recipes for catching fish and other underwater items."],
          type = "toggle",
          width = 1.5,
          order = 105,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
        },
        colorFishingRecipes = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Fishing Recipes"]),
          type = "color",
          order = 106,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
          get = function()
            local color = self.db.profile.color.FishingRecipes
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.FishingRecipes
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_14 = {
          type = "header",
          name = "",
          order = 107,
        },
        moveLeatherworkingRecipes = {
          name = L["Leatherworking Recipes"],
          desc = L["Recipes for crafting leather and mail armor."],
          type = "toggle",
          width = 1.5,
          order = 108,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
        },
        colorLeatherworkingRecipes = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Leatherworking Recipes"]),
          type = "color",
          order = 109,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
          get = function()
            local color = self.db.profile.color.LeatherworkingRecipes
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.LeatherworkingRecipes
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_15 = {
          type = "header",
          name = "",
          order = 110,
        },
        moveTailoringRecipes = {
          name = L["Tailoring Recipes"],
          desc = L["Recipes for weaving cloth armor and other cloth items."],
          type = "toggle",
          width = 1.5,
          order = 111,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
        },
        colorTailoringRecipes = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Tailoring Recipes"]),
          type = "color",
          order = 112,
          disabled = function()
            return self.db.profile.moveMergedRecipes
          end,
          get = function()
            local color = self.db.profile.color.TailoringRecipes
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.TailoringRecipes
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    TemporaryPermanentEnhancements_config = {
      type = "group",
      name = L["Temporary & Permanent Enhancements"],
      desc = "", -- doesnt work,
      inline = true,
      order = 113,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Use these for a powerup!"],
          order = 114,
        },
        moveMergedTemporaryPermanentEnhancements = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Temporary & Permanent Enhancements"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Temporary & Permanent Enhancements"]),
          type = "toggle",
          width = 1.5,
          order = 115,
        },
        colorMergedTemporaryPermanentEnhancements = {
          name = L["Color"],
          desc = string.format(
            L["Select a color for the merged %s category."],
            L["Temporary & Permanent Enhancements"]
          ),
          type = "color",
          order = 116,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedTemporaryPermanentEnhancements
          end,
          get = function()
            local color = self.db.profile.color.mergedTemporaryPermanentEnhancements
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedTemporaryPermanentEnhancements
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_16 = {
          type = "header",
          name = "",
          order = 117,
        },
        movePermanentEnhancements = {
          name = L["Permanent Enhancements"],
          desc = L["These are permanent enhancements that you can typically apply to armor to improve it."],
          type = "toggle",
          width = 1.5,
          order = 118,
          disabled = function()
            return self.db.profile.moveMergedTemporaryPermanentEnhancements
          end,
        },
        colorPermanentEnhancements = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Permanent Enhancements"]),
          type = "color",
          order = 119,
          disabled = function()
            return self.db.profile.moveMergedTemporaryPermanentEnhancements
          end,
          get = function()
            local color = self.db.profile.color.PermanentEnhancements
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.PermanentEnhancements
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_17 = {
          type = "header",
          name = "",
          order = 120,
        },
        moveTemporaryEnhancements = {
          name = L["Temporary Enhancements"],
          desc = L["These are temporary enhancements that you can typically apply to armor to improve it."],
          type = "toggle",
          width = 1.5,
          order = 121,
          disabled = function()
            return self.db.profile.moveMergedTemporaryPermanentEnhancements
          end,
        },
        colorTemporaryEnhancements = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Temporary Enhancements"]),
          type = "color",
          order = 122,
          disabled = function()
            return self.db.profile.moveMergedTemporaryPermanentEnhancements
          end,
          get = function()
            local color = self.db.profile.color.TemporaryEnhancements
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.TemporaryEnhancements
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    Tradegoods_config = {
      type = "group",
      name = L["Tradegoods"],
      desc = "", -- doesnt work,
      inline = true,
      order = 123,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Trading tradegoods is good. Trade tradegoods for good goods."],
          order = 124,
        },
        moveMergedTradegoods = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Tradegoods"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Tradegoods"]),
          type = "toggle",
          width = 1.5,
          order = 125,
        },
        colorMergedTradegoods = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["Tradegoods"]),
          type = "color",
          order = 126,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.mergedTradegoods
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedTradegoods
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_18 = {
          type = "header",
          name = "",
          order = 127,
        },
        moveCloth = {
          name = L["Cloth"],
          desc = L["Cloth used in Tailoring."],
          type = "toggle",
          width = 1.5,
          order = 128,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorCloth = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Cloth"]),
          type = "color",
          order = 129,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.Cloth
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Cloth
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_19 = {
          type = "header",
          name = "",
          order = 130,
        },
        moveElemental = {
          name = L["Elemental"],
          desc = L["Elementals used in all professions."],
          type = "toggle",
          width = 1.5,
          order = 131,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorElemental = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Elemental"]),
          type = "color",
          order = 132,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.Elemental
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Elemental
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_20 = {
          type = "header",
          name = "",
          order = 133,
        },
        moveEnchanting = {
          name = L["Enchanting"],
          desc = L["Enchanting materials for enchanting weapons & armor."],
          type = "toggle",
          width = 1.5,
          order = 134,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorEnchanting = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Enchanting"]),
          type = "color",
          order = 135,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.Enchanting
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Enchanting
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_21 = {
          type = "header",
          name = "",
          order = 136,
        },
        moveHerbs = {
          name = L["Herbs"],
          desc = L["Herbs used in Alchemy & Inscription."],
          type = "toggle",
          width = 1.5,
          order = 137,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorHerbs = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Herbs"]),
          type = "color",
          order = 138,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.Herbs
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Herbs
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_22 = {
          type = "header",
          name = "",
          order = 139,
        },
        moveInscription = {
          name = L["Inscription"],
          desc = L["Inscription materials for creating glyphs or other paper related goods."],
          type = "toggle",
          width = 1.5,
          order = 140,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorInscription = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Inscription"]),
          type = "color",
          order = 141,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.Inscription
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Inscription
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_23 = {
          type = "header",
          name = "",
          order = 142,
        },
        moveJewelcrafting = {
          name = L["Jewelcrafting"],
          desc = L["Jewelcrafting materials for creating rings, necklaces, gems, etc."],
          type = "toggle",
          width = 1.5,
          order = 143,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorJewelcrafting = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Jewelcrafting"]),
          type = "color",
          order = 144,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.Jewelcrafting
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Jewelcrafting
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_24 = {
          type = "header",
          name = "",
          order = 145,
        },
        moveLeather = {
          name = L["Leather"],
          desc = L["Leather used in Leatherworking."],
          type = "toggle",
          width = 1.5,
          order = 146,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorLeather = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Leather"]),
          type = "color",
          order = 147,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.Leather
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Leather
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_25 = {
          type = "header",
          name = "",
          order = 148,
        },
        moveMeatFish = {
          name = L["Meat & Fish"],
          desc = L["Meat & Fish used in Cooking."],
          type = "toggle",
          width = 1.5,
          order = 149,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorMeatFish = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Meat & Fish"]),
          type = "color",
          order = 150,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.MeatFish
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.MeatFish
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_26 = {
          type = "header",
          name = "",
          order = 151,
        },
        moveMetalStone = {
          name = L["Metal & Stone"],
          desc = L["Metal & Stone used in Blacksmithing."],
          type = "toggle",
          width = 1.5,
          order = 152,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorMetalStone = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Metal & Stone"]),
          type = "color",
          order = 153,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.MetalStone
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.MetalStone
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_27 = {
          type = "header",
          name = "",
          order = 154,
        },
        moveOtherTradegoods = {
          name = L["Other Tradegoods"],
          desc = L["Other items used in various professions."],
          type = "toggle",
          width = 1.5,
          order = 155,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorOtherTradegoods = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Other Tradegoods"]),
          type = "color",
          order = 156,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.OtherTradegoods
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.OtherTradegoods
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_28 = {
          type = "header",
          name = "",
          order = 157,
        },
        moveParts = {
          name = L["Parts"],
          desc = L["Parts used in Engineering."],
          type = "toggle",
          width = 1.5,
          order = 158,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
        },
        colorParts = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Parts"]),
          type = "color",
          order = 159,
          disabled = function()
            return self.db.profile.moveMergedTradegoods
          end,
          get = function()
            local color = self.db.profile.color.Parts
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Parts
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
  },
    AdiBags:GetOptionHandler(self, false, function()
      return self:Update()
    end)
end
